@@ -24,7 +24,7 @@ OSDefineMetaClassAndStructors (AppleUSBAudioDevice, super)
 bool AppleUSBAudioDevice::init (OSDictionary * properties)  {
 	bool		resultCode;
 
-	debug2IOLog ("+AppleUSBAudioDevice[%p]::init ()\n", this);
+	debugIOLog ("+AppleUSBAudioDevice[%p]::init ()", this);
 	resultCode = FALSE;		// Assume failure
 
 	// get the IOAudioDevice generic initialization
@@ -33,12 +33,12 @@ bool AppleUSBAudioDevice::init (OSDictionary * properties)  {
 	resultCode = TRUE;
 
 Exit:
-	debug2IOLog ("-AppleUSBAudioDevice[%p]::init ()\n", this);
+	debugIOLog ("-AppleUSBAudioDevice[%p]::init ()", this);
 	return resultCode;
 }
 
 void AppleUSBAudioDevice::free () {
-    debug2IOLog ("+AppleUSBAudioDevice[%p]::free ()\n", this);
+    debugIOLog ("+AppleUSBAudioDevice[%p]::free ()", this);
 
     if (interfaceLock) {
         IORecursiveLockFree (interfaceLock);
@@ -51,12 +51,12 @@ void AppleUSBAudioDevice::free () {
     }
 
     super::free ();
-    debug2IOLog ("-AppleUSBAudioDevice[%p]::free ()\n", this);
+    debugIOLog ("-AppleUSBAudioDevice[%p]::free ()", this);
 }
 
 bool AppleUSBAudioDevice::requestTerminate (IOService * provider, IOOptionBits options) {
-	debug4IOLog ("+AppleUSBAudioDevice[%p]::requestTerminate (%p, %x)\n", this, provider, options);
-	debug4IOLog ("-AppleUSBAudioDevice[%p]::requestTerminate (%p, %x)\n", this, provider, options);
+	debugIOLog ("+AppleUSBAudioDevice[%p]::requestTerminate (%p, %x)", this, provider, options);
+	debugIOLog ("-AppleUSBAudioDevice[%p]::requestTerminate (%p, %x)", this, provider, options);
 	return TRUE;		// it is OK to terminate us
 }
 
@@ -71,7 +71,7 @@ bool AppleUSBAudioDevice::ControlsStreamNumber (UInt8 streamNumber) {
 	if (usbAudio) {
 		usbAudio->GetControlledStreamNumbers (&streamNumbers, &numStreams);
 		for (index = 0; index < numStreams; index++) {
-			debug3IOLog ("Checking stream %d against controled stream %d\n", streamNumber, streamNumbers[index]);
+			debugIOLog ("Checking stream %d against controled stream %d", streamNumber, streamNumbers[index]);
 			if (streamNumber == streamNumbers[index]) {
 				doesControl = TRUE;
 				break;				// get out of for loop
@@ -85,7 +85,7 @@ bool AppleUSBAudioDevice::ControlsStreamNumber (UInt8 streamNumber) {
 bool AppleUSBAudioDevice::start (IOService * provider) {
 	bool								result;
 
-    debug3IOLog ("+ AppleUSBAudioDevice[%p]::start (%p)\n", this, provider);
+    debugIOLog ("+ AppleUSBAudioDevice[%p]::start (%p)", this, provider);
 	result = FALSE;
 
 	controlInterface = OSDynamicCast (IOUSBInterface, provider);
@@ -94,7 +94,7 @@ bool AppleUSBAudioDevice::start (IOService * provider) {
 	mInitHardwareThread = thread_call_allocate ((thread_call_func_t)AppleUSBAudioDevice::initHardwareThread, (thread_call_param_t)this);
 	FailIf (NULL == mInitHardwareThread, Exit);
 
-    debug3IOLog ("- AppleUSBAudioDevice[%p]::start (%p)\n", this, provider);
+    debugIOLog ("- AppleUSBAudioDevice[%p]::start (%p)", this, provider);
 
 	result = super::start (provider);				// Causes our initHardware routine to be called.
 
@@ -155,19 +155,19 @@ IOReturn AppleUSBAudioDevice::protectedInitHardware (IOService * provider) {
 	UInt8 *							streamNumbers;
 	UInt8							numStreams;
 
-	debug3IOLog ("+AppleUSBAudioDevice[%p]::start (%p)\n", this, provider);
+	debugIOLog ("+AppleUSBAudioDevice[%p]::start (%p)", this, provider);
 
 	resultCode = FALSE;
 
-	debug2IOLog ("There are %d configurations on this device\n", controlInterface->GetDevice()->GetNumConfigurations ());
-	debug2IOLog ("Our control interface number is %d\n", controlInterface->GetInterfaceNumber ());
+	debugIOLog ("There are %d configurations on this device", controlInterface->GetDevice()->GetNumConfigurations ());
+	debugIOLog ("Our control interface number is %d", controlInterface->GetInterfaceNumber ());
 	usbAudio = USBAudioConfigObject::create (controlInterface->GetDevice()->GetFullConfigurationDescriptor (0), controlInterface->GetInterfaceNumber ());
 	FailIf (NULL == usbAudio, Exit);
 
 	// Check to make sure that the control interface we loaded against has audio streaming interfaces and not just MIDI.
 	usbAudio->GetControlledStreamNumbers (&streamNumbers, &numStreams);
-	debug2IOLog ("Num streams controlled = %d\n", numStreams);
-	debug2IOLog ("GetNumStreamInterfaces = %d\n", usbAudio->GetNumStreamInterfaces ());
+	debugIOLog ("Num streams controlled = %d", numStreams);
+	debugIOLog ("GetNumStreamInterfaces = %d", usbAudio->GetNumStreamInterfaces ());
 	FailIf (0 == numStreams, Exit);
 
 	// If this is an iSub, we need to not go any further because we don't support it in this driver
@@ -212,7 +212,7 @@ IOReturn AppleUSBAudioDevice::protectedInitHardware (IOService * provider) {
 	resultCode = super::initHardware (provider);
 
 Exit:
-	debug3IOLog ("-AppleUSBAudioDevice[%p]::start (%p)\n", this, provider);
+	debugIOLog ("-AppleUSBAudioDevice[%p]::start (%p)", this, provider);
 
 	return TRUE;
 }
@@ -221,13 +221,13 @@ void AppleUSBAudioDevice::streamStopped (IOAudioEngine *audioEngine) {
     // This must be called from within the workLoop
     // The AppleUSBAudioEngine does so from _setState()
     // which has the same requirement
-    debugIOLog ("+AppleUSBAudioDevice::streamStopped ()\n");
+    debugIOLog ("+AppleUSBAudioDevice::streamStopped ()");
     
     if (allStreamsStopped()) {
         terminate();
     }
     
-    debugIOLog ("-AppleUSBAudioDevice::streamStopped ()\n");
+    debugIOLog ("-AppleUSBAudioDevice::streamStopped ()");
 }
 
 bool AppleUSBAudioDevice::allStreamsStopped () {
@@ -235,7 +235,7 @@ bool AppleUSBAudioDevice::allStreamsStopped () {
     IOAudioEngine *					audioEngine;
     bool							result;
 
-    debug2IOLog ("+AppleUSBAudioDevice[%p]::allStreamsStopped ()\n", this);
+    debugIOLog ("+AppleUSBAudioDevice[%p]::allStreamsStopped ()", this);
     result = TRUE;
 
     FailIf (NULL == audioEngines, Exit);
@@ -257,19 +257,19 @@ bool AppleUSBAudioDevice::allStreamsStopped () {
     }
 
 Exit:
-    debug2IOLog ("-AppleUSBAudioDevice[%p]::allStreamsStopped ()\n", this);
+    debugIOLog ("-AppleUSBAudioDevice[%p]::allStreamsStopped ()", this);
     return result;
 }
 */
 IOReturn AppleUSBAudioDevice::performPowerStateChange (IOAudioDevicePowerState oldPowerState, IOAudioDevicePowerState newPowerState, UInt32 *microSecsUntilComplete) {
 	IOReturn						result;
 
-	debug4IOLog ("+AppleUSBAudioDevice::performPowerStateChange (%d, %d, %p)\n", oldPowerState, newPowerState, microSecsUntilComplete);
+	debugIOLog ("+AppleUSBAudioDevice[%p]::performPowerStateChange (%d, %d, %p)", this, oldPowerState, newPowerState, microSecsUntilComplete);
 
 	result = super::performPowerStateChange (oldPowerState, newPowerState, microSecsUntilComplete);
 
 	if (oldPowerState == kIOAudioDeviceSleep) {
-		debugIOLog ("Waking from sleep - flushing controls to the device.\n");
+		debugIOLog ("Waking from sleep - flushing controls to the device.");
 		flushAudioControls ();
 	}
 
@@ -279,7 +279,7 @@ IOReturn AppleUSBAudioDevice::performPowerStateChange (IOAudioDevicePowerState o
 void AppleUSBAudioDevice::stop (IOService *provider) {
 	bool			shouldStop;
 
-	debug5IOLog ("+AppleUSBAudioDevice[%p]::stop (%p) - audioEngines = %p - rc=%d\n", this, provider, audioEngines, getRetainCount());
+	debugIOLog ("+AppleUSBAudioDevice[%p]::stop (%p) - audioEngines = %p - rc=%d", this, provider, audioEngines, getRetainCount());
 
 	shouldStop = TRUE;
 
@@ -287,7 +287,7 @@ void AppleUSBAudioDevice::stop (IOService *provider) {
 		performStop (provider);
 	}
 
-	debug2IOLog("-AppleUSBAudioDevice[%p]::stop ()\n", this);
+	debugIOLog("-AppleUSBAudioDevice[%p]::stop ()", this);
 }
 
 // Return FALSE if you don't want PRAM updated on a volume change, TRUE if you want it updated.
@@ -310,11 +310,11 @@ Boolean AppleUSBAudioDevice::ShouldUpdatePRAM (void) {
 
 	// Make sure they're speakers that can support boot beep
 	vendorID = controlInterface->GetDevice()->GetVendorID ();
-	debug2IOLog ("+ ShouldUpdatePRAM\nspeaker's vendorID = 0x%x\n", vendorID);
+	debugIOLog ("+ ShouldUpdatePRAM\nspeaker's vendorID = 0x%x", vendorID);
 	if (kIOUSBVendorIDAppleComputer == vendorID || kIOUSBVendorIDHaronKardon == vendorID || kIOUSBVendorMicronas == vendorID) {
 		speakersGood = TRUE;
 	}
-	debug2IOLog ("speakersGood = %d\n", speakersGood);
+	debugIOLog ("speakersGood = %d", speakersGood);
 
 	// They have to be plugged into a root hub or a hub in monitor that can support boot beep
 	if (TRUE == speakersGood) {
@@ -329,7 +329,7 @@ Boolean AppleUSBAudioDevice::ShouldUpdatePRAM (void) {
 		FailIf (NULL == number, Exit);
 
 		vendorID = number->unsigned32BitValue ();
-		debug2IOLog ("hub's vendorID = 0x%x\n", vendorID);
+		debugIOLog ("hub's vendorID = 0x%x", vendorID);
 
 		if (kIOUSBVendorIDAppleComputer == vendorID) {
 			obj = usbRegEntry->getProperty (kUSBDevicePropertyLocationID);
@@ -339,24 +339,24 @@ Boolean AppleUSBAudioDevice::ShouldUpdatePRAM (void) {
 			if (OSDynamicCast (IOUSBRootHubDevice, usbRegEntry)) {
 				// It's connected to the root hub
 				connectionGood = TRUE;
-				debugIOLog ("Directly connected to the root hub\n");
+				debugIOLog ("Directly connected to the root hub");
 			} else {
 				obj = usbRegEntry->getProperty (kUSBProductID);
 				number = OSDynamicCast (OSNumber, obj);
 				FailIf (NULL == number, Exit);
 
 				productID = number->unsigned32BitValue ();
-				debug2IOLog ("hub's productID = 0x%x\n", productID);
+				debugIOLog ("hub's productID = 0x%x", productID);
 
 				if (kStudioDisplay15CRT == productID || kStudioDisplay17CRT == productID || kCinemaDisplay == productID || kStudioDisplay17FP == productID) {
 					// It's connected to a good monitor
 					connectionGood = TRUE;
-					debugIOLog ("Connected to a capable monitor\n");
+					debugIOLog ("Connected to a capable monitor");
 				}
 			}
 		}
 	}
-	debug2IOLog ("connectionGood = %d\n", connectionGood);
+	debugIOLog ("connectionGood = %d", connectionGood);
 
 	// And there CANNOT be a "sound" node in the device tree so that OF will boot beep through them
 	if (TRUE == connectionGood && FALSE == FindSoundNode ()) {
@@ -364,7 +364,7 @@ Boolean AppleUSBAudioDevice::ShouldUpdatePRAM (void) {
 	}
 
 Exit:
-	debug2IOLog ("- ShouldUpdatePRAM result = %d\n", result);
+	debugIOLog ("- ShouldUpdatePRAM result = %d", result);
 	return result;
 }
 
@@ -415,7 +415,7 @@ Exit:
 
 void AppleUSBAudioDevice::performStop (IOService *provider) {
 
-    debug3IOLog("+AppleUSBAudioDevice[%p]::performStop (%p)\n", this, provider);
+    debugIOLog("+AppleUSBAudioDevice[%p]::performStop (%p)", this, provider);
 
 	super::stop (provider);  // call the IOAudioDevice generic stop routine
 
@@ -424,7 +424,7 @@ void AppleUSBAudioDevice::performStop (IOService *provider) {
         controlInterface = NULL;
     }
 
-    debug3IOLog ("-AppleUSBAudioDevice[%p]::performStop (%p)\n", this, provider);
+    debugIOLog ("-AppleUSBAudioDevice[%p]::performStop (%p)", this, provider);
 }
 
 bool AppleUSBAudioDevice::terminate (IOOptionBits options) {
@@ -433,30 +433,30 @@ bool AppleUSBAudioDevice::terminate (IOOptionBits options) {
 
 	shouldTerminate = TRUE;
 	result = TRUE;
-	debug3IOLog ("+AppleUSBAudioDevice[%p]::terminate () - rc=%d\n", this, getRetainCount ());
+	debugIOLog ("+AppleUSBAudioDevice[%p]::terminate () - rc=%d", this, getRetainCount ());
 
 	if (shouldTerminate) {
 		result = super::terminate (options);
 	}
 
-	debug3IOLog ("-AppleUSBAudioDevice[%p]::terminate () - rc=%d\n", this, getRetainCount ());
+	debugIOLog ("-AppleUSBAudioDevice[%p]::terminate () - rc=%d", this, getRetainCount ());
 
 	return result;
 }
 
 bool AppleUSBAudioDevice::finalize (IOOptionBits options) {
 	bool result;
-	debug4IOLog ("+AppleUSBAudioDevice[%p]::finalize (%p) - rc=%d\n", this, options, getRetainCount ());
+	debugIOLog ("+AppleUSBAudioDevice[%p]::finalize (%p) - rc=%d", this, options, getRetainCount ());
 
 	result = super::finalize (options);
 
-	debug4IOLog ("-AppleUSBAudioDevice[%p]::finalize (%p) - rc=%d\n", this, options, getRetainCount ());
+	debugIOLog ("-AppleUSBAudioDevice[%p]::finalize (%p) - rc=%d", this, options, getRetainCount ());
 
 	return result;
 }
 
 IOReturn AppleUSBAudioDevice::message (UInt32 type, IOService * provider, void * arg) {
-	debug5IOLog ("+AppleUSBAudioDevice[%p]::message (0x%x, %p) - rc=%d\n", this, type, provider, getRetainCount ());
+	debugIOLog ("+AppleUSBAudioDevice[%p]::message (0x%x, %p) - rc=%d", this, type, provider, getRetainCount ());
 
 	switch (type) {
 		case kIOMessageServiceIsTerminated:
@@ -469,7 +469,7 @@ IOReturn AppleUSBAudioDevice::message (UInt32 type, IOService * provider, void *
 			;
 	}
 
-	debug5IOLog ("-AppleUSBAudioDevice[%p]::message (0x%x, %p) - rc=%d\n", this, type, provider, getRetainCount ());
+	debugIOLog ("-AppleUSBAudioDevice[%p]::message (0x%x, %p) - rc=%d", this, type, provider, getRetainCount ());
 	return kIOReturnSuccess;
 }
 
@@ -488,7 +488,7 @@ IOReturn AppleUSBAudioDevice::createControlsForInterface (IOAudioEngine *audioEn
 	UInt8								controlInterfaceNum;
 	Boolean								shouldUpdatePRAM;
 
-    debug4IOLog ("+AppleUSBAudioDevice[%p]::createControlsForInterface %d %d\n", this, interfaceNum, altInterfaceNum);
+    debugIOLog ("+AppleUSBAudioDevice[%p]::createControlsForInterface %d %d", this, interfaceNum, altInterfaceNum);
 
     result = kIOReturnError;
 	terminatingDriver = FALSE;
@@ -505,14 +505,14 @@ IOReturn AppleUSBAudioDevice::createControlsForInterface (IOAudioEngine *audioEn
 		// look for a streaming input terminal that's connected to a non-streaming output terminal
 		// for the moment we'll just look for a feature unit connected to a non-streaming output terminal
 		numTerminals = usbAudio->GetNumOutputTerminals (controlInterfaceNum, 0);
-		debug2IOLog ("num output terminals = %d\n", numTerminals);
+		debugIOLog ("num output terminals = %d", numTerminals);
 		for (terminalIndex = 0; terminalIndex < numTerminals; terminalIndex++) {
-			debug2IOLog ("terminalIndex = 0x%X\n", terminalIndex);
+			debugIOLog ("terminalIndex = 0x%X", terminalIndex);
 			terminalType = usbAudio->GetIndexedOutputTerminalType (controlInterfaceNum, 0, terminalIndex);
-			debug2IOLog ("terminalType = 0x%X\n", terminalType);
+			debugIOLog ("terminalType = 0x%X", terminalType);
 			if (terminalType != 0x0101) {	// Only look for output terminals that output audio (things we can play to)
 				featureUnitID = usbAudio->GetFeatureUnitIDConnectedToOutputTerminal (controlInterfaceNum, 0, usbAudio->GetIndexedOutputTerminalID (controlInterfaceNum, 0, terminalIndex));
-				debug2IOLog ("featureUnitID = %d\n", featureUnitID);
+				debugIOLog ("featureUnitID = %d", featureUnitID);
 				break;	// get out of for loop
 			}
 		}
@@ -553,7 +553,7 @@ IOReturn AppleUSBAudioDevice::createControlsForInterface (IOAudioEngine *audioEn
 					audioEngine->addDefaultAudioControl (speakerControl);
 					speakerControl->release ();
 				} else {
-					debug2IOLog ("++AppleUSBAudioDevice::createControlsForInterface () - error creating volume control for channelNum %d\n", channelNum);
+					debugIOLog ("++AppleUSBAudioDevice::createControlsForInterface () - error creating volume control for channelNum %d", channelNum);
 				}
 			}
 		}
@@ -570,7 +570,7 @@ IOReturn AppleUSBAudioDevice::createControlsForInterface (IOAudioEngine *audioEn
 					audioEngine->addDefaultAudioControl (muteControl);
 					muteControl->release ();
 				} else {
-					debug2IOLog ("++AppleUSBAudioDevice::createControlsForInterface () - error creating mute control for channelNum %d\n", channelNum);
+					debugIOLog ("++AppleUSBAudioDevice::createControlsForInterface () - error creating mute control for channelNum %d", channelNum);
 				}
 			}
 		}
@@ -580,21 +580,21 @@ IOReturn AppleUSBAudioDevice::createControlsForInterface (IOAudioEngine *audioEn
 		// look for a streaming input terminal that's connected to a non-streaming output terminal
 		// for the moment we'll just look for a feature unit connected to a non-streaming output terminal
 		numTerminals = usbAudio->GetNumOutputTerminals (controlInterfaceNum, 0);
-		debug2IOLog ("num output terminals = %d\n", numTerminals);
+		debugIOLog ("num output terminals = %d", numTerminals);
 		for (terminalIndex = 0; terminalIndex < numTerminals; terminalIndex++) {
-			debug2IOLog ("terminalIndex = 0x%X\n", terminalIndex);
+			debugIOLog ("terminalIndex = 0x%X", terminalIndex);
 			terminalType = usbAudio->GetIndexedOutputTerminalType (controlInterfaceNum, 0, terminalIndex);
-			debug2IOLog ("terminalType = 0x%X\n", terminalType);
+			debugIOLog ("terminalType = 0x%X", terminalType);
 			if (terminalType == 0x0101) {	// Only look for output terminals that output digital audio data (things we can record from)
 				featureUnitID = usbAudio->GetFeatureUnitIDConnectedToOutputTerminal (controlInterfaceNum, 0, usbAudio->GetIndexedOutputTerminalID (controlInterfaceNum, 0, terminalIndex));
-				debug2IOLog ("featureUnitID = %d\n", featureUnitID);
+				debugIOLog ("featureUnitID = %d", featureUnitID);
 				break;	// get out of for loop
 			}
 		}
 		FailWithAction (0 == featureUnitID, result = kIOReturnSuccess, Exit);	// There isn't a feature unit connected to this output terminal
 		// The interface was opened in AppleUSBAudioEngine::initHardware
 		controlInterface->SetAlternateInterface (this, kRootAlternateSetting);
-		debug2IOLog ("There are %d controls\n", usbAudio->GetNumChannels (interfaceNum, altInterfaceNum));
+		debugIOLog ("There are %d controls", usbAudio->GetNumChannels (interfaceNum, altInterfaceNum));
 		for (channelNum = 0; channelNum <= usbAudio->GetNumChannels (interfaceNum, altInterfaceNum); channelNum++) {
 			if (usbAudio->ChannelHasVolumeControl (controlInterfaceNum, 0, featureUnitID, channelNum)) {
 				micControl = AppleUSBAudioLevelControl::create (featureUnitID,
@@ -611,10 +611,10 @@ IOReturn AppleUSBAudioDevice::createControlsForInterface (IOAudioEngine *audioEn
 					audioEngine->addDefaultAudioControl (micControl);
 					micControl->release ();
 				} else {
-					debug2IOLog ("++AppleUSBAudioDevice::createControlsForInterface () - error creating volume control for channelNum %d\n", channelNum);
+					debugIOLog ("++AppleUSBAudioDevice::createControlsForInterface () - error creating volume control for channelNum %d", channelNum);
 				}
 			} else {
-				debug2IOLog ("channel %d doesn't have a volume control\n", channelNum);
+				debugIOLog ("channel %d doesn't have a volume control", channelNum);
 			}
 		}
 		muteControl = NULL;
@@ -630,7 +630,7 @@ IOReturn AppleUSBAudioDevice::createControlsForInterface (IOAudioEngine *audioEn
 					audioEngine->addDefaultAudioControl (muteControl);
 					muteControl->release ();
 				} else {
-					debug2IOLog ("++AppleUSBAudioDevice::createControlsForInterface () - error creating mute control for channelNum %d\n", channelNum);
+					debugIOLog ("++AppleUSBAudioDevice::createControlsForInterface () - error creating mute control for channelNum %d", channelNum);
 				}
 			}
 		}
@@ -643,18 +643,18 @@ Exit:
 IOReturn AppleUSBAudioDevice::activateAudioEngine (IOAudioEngine *audioEngine, bool shouldStartAudioEngine, UInt8 interfaceNum, UInt8 altInterfaceNum) {
     IOReturn							result;
 
-    debug5IOLog ("+AppleUSBAudioDevice[%p]::activateAudioEngine (%p, %d) - rc=%d\n", this, audioEngine, shouldStartAudioEngine, getRetainCount());
+    debugIOLog ("+AppleUSBAudioDevice[%p]::activateAudioEngine (%p, %d) - rc=%d", this, audioEngine, shouldStartAudioEngine, getRetainCount());
 
     result = super::activateAudioEngine (audioEngine, shouldStartAudioEngine);
 
-    debug4IOLog ("-AppleUSBAudioDevice[%p]::activateAudioEngine (%p) - rc=%d\n", this, audioEngine, getRetainCount ());
+    debugIOLog ("-AppleUSBAudioDevice[%p]::activateAudioEngine (%p) - rc=%d", this, audioEngine, getRetainCount ());
     return result;
 }
 
 IOReturn AppleUSBAudioDevice::deviceRequest (IOUSBDevRequest *request, AppleUSBAudioDevice * self, IOUSBCompletion *completion) {
 	IOReturn						result;
 
-	debug4IOLog ("+AppleUSBAudioDevice[%p]::deviceRequest (%p, %p)\n", self, request, completion);
+	debugIOLog ("+AppleUSBAudioDevice[%p]::deviceRequest (%p, %p)", self, request, completion);
 	result = kIOReturnSuccess;
 	if (self->controlInterface && FALSE == self->terminatingDriver) {
 		FailIf (NULL == self->interfaceLock, Exit);
@@ -664,20 +664,20 @@ IOReturn AppleUSBAudioDevice::deviceRequest (IOUSBDevRequest *request, AppleUSBA
         IORecursiveLockUnlock (self->interfaceLock);
     }
 
-	debug4IOLog ("-AppleUSBAudioDevice[%p]::deviceRequest (%p, %p)\n", self, request, completion);
+	debugIOLog ("-AppleUSBAudioDevice[%p]::deviceRequest (%p, %p)", self, request, completion);
 
 Exit:
 	return result;
 }
 
 bool AppleUSBAudioDevice::willTerminate (IOService * provider, IOOptionBits options) {
-	debug3IOLog ("+AppleUSBAudioDevice[%p]::willTerminate (%p)\n", this, provider);
+	debugIOLog ("+AppleUSBAudioDevice[%p]::willTerminate (%p)", this, provider);
 
 	if (controlInterface == provider) {
 		terminatingDriver = TRUE;
 	}
 
-	debug2IOLog ("-AppleUSBAudioDevice[%p]::willTerminate\n", this);
+	debugIOLog ("-AppleUSBAudioDevice[%p]::willTerminate", this);
 
 	return super::willTerminate (provider, options);
 }
@@ -687,13 +687,13 @@ bool AppleUSBAudioDevice::willTerminate (IOService * provider, IOOptionBits opti
 
 void AppleUSBAudioDevice::retain() const
 {
-//    debug3IOLog("AppleUSBAudioDevice(%p)::retain() - rc=%d\n", this, getRetainCount());
+//    debugIOLog("AppleUSBAudioDevice(%p)::retain() - rc=%d", this, getRetainCount());
     super::retain();
 }
 
 void AppleUSBAudioDevice::release() const
 {
-//    debug3IOLog("AppleUSBAudioDevice(%p)::release() - rc=%d\n", this, getRetainCount());
+//    debugIOLog("AppleUSBAudioDevice(%p)::release() - rc=%d", this, getRetainCount());
 	super::release();
 }
 
