@@ -144,7 +144,6 @@ protected:
 	UInt32								safeToEraseTo;
 	UInt32								lastSafeErasePoint;
 	UInt32								theStartBufferSize;
-	UInt32								previous;
 	UInt32								previousClippedToFrame;
 	UInt32								readUSBFrameListSize;
 	UInt32								bufferOffset;
@@ -240,7 +239,7 @@ protected:
     virtual IOAudioStreamDirection getDirection (void);
     virtual void *getSampleBuffer (void);
 	virtual UInt32 getSampleBufferSize (void);
-	virtual void CoalesceInputSamples (UInt32 numBytesToCoalesce, IOUSBLowLatencyIsocFrame * pFrames);
+	virtual void CoalesceInputSamples (UInt32 numBytesToCoalesce, IOUSBLowLatencyIsocFrame * pFrames, UInt32 startingFrameList);
 	virtual void resetClipPosition (IOAudioStream *audioStream, UInt32 clipSampleFrame);
     virtual IOReturn clipOutputSamples (const void *mixBuf, void *sampleBuf, UInt32 firstSampleFrame, UInt32 numSampleFrames, const IOAudioStreamFormat *streamFormat, IOAudioStream *audioStream);
 	virtual IOReturn convertInputSamples (const void *sampleBuf, void *destBuf, UInt32 firstSampleFrame, UInt32 numSampleFrames, const IOAudioStreamFormat *streamFormat, IOAudioStream *audioStream);
