@@ -7,7 +7,7 @@ OSDefineMetaClassAndStructors(AppleUSBAudioLevelControl, IOAudioLevelControl)
 AppleUSBAudioLevelControl *AppleUSBAudioLevelControl::create (UInt8 theUnitID, UInt8 theInterfaceNumber, UInt8 theControlSelector, UInt8 theChannelNumber, Boolean shouldUpdatePRAM, USBDeviceRequest theUSBDeviceRequest, void *theCallerRefCon, UInt32 subType, UInt32 usage) {
     AppleUSBAudioLevelControl *			control;
 
-    debug8IOLog ("+AppleUSBAudioLevelControl::create (%d, %d, %d, %d, %p, %lX, %lX)\n", theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, subType, usage);
+    debugIOLog ("+AppleUSBAudioLevelControl::create (%d, %d, %d, %d, %p, %lX, %lX)", theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, subType, usage);
     control = new AppleUSBAudioLevelControl;
     FailIf (NULL == control, Exit);
 
@@ -17,7 +17,7 @@ AppleUSBAudioLevelControl *AppleUSBAudioLevelControl::create (UInt8 theUnitID, U
     }
 
 Exit:
-    debug8IOLog ("-AppleUSBAudioLevelControl::create(%d, %d, %d, %d, %p, %lX, %lX)\n", theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, subType, usage);
+    debugIOLog ("-AppleUSBAudioLevelControl::create(%d, %d, %d, %d, %p, %lX, %lX)", theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, subType, usage);
     return control;
 }
 
@@ -33,7 +33,7 @@ bool AppleUSBAudioLevelControl::init (UInt8 theUnitID, UInt8 theInterfaceNumber,
 	Boolean						result;
 	Boolean						arePRAMControl;
 
-	debug8IOLog ("+AppleUSBAudioLevelControl[%p]::init (%d, %d, %d, %d, %p, %p)\n", this, theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, properties);
+	debugIOLog ("+AppleUSBAudioLevelControl[%p]::init (%d, %d, %d, %d, %p, %p)", this, theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, properties);
 	result = FALSE;
 	arePRAMControl = FALSE;
 
@@ -73,7 +73,7 @@ bool AppleUSBAudioLevelControl::init (UInt8 theUnitID, UInt8 theInterfaceNumber,
 			channelName = kIOAudioControlChannelNameRight;
 			break;
 		case 0xff:
-			debugIOLog ("++AppleUSBAudioLevelControl: Does not support channel number 0xff.\n");
+			debugIOLog ("++AppleUSBAudioLevelControl: Does not support channel number 0xff.");
 			return FALSE;
 		default:
 			channelName = "Unknown";
@@ -82,21 +82,21 @@ bool AppleUSBAudioLevelControl::init (UInt8 theUnitID, UInt8 theInterfaceNumber,
 
 	currentValue = GetCurVolume (interfaceNumber, channelNumber, &ret);
 	FailIf (kIOReturnSuccess != ret, Exit);
-	debug3IOLog ("channelNumber %d, currentValue = 0x%X, ", channelNumber, currentValue);
+	debugIOLog ("channelNumber %d, currentValue = 0x%X, ", channelNumber, currentValue);
 	volRes = GetVolumeResolution (interfaceNumber, channelNumber, &ret);
 	FailIf (kIOReturnSuccess != ret, Exit);
-	debug2IOLog ("vol res = %d, ", volRes);
+	debugIOLog ("vol res = %d, ", volRes);
 	deviceMin = GetMinVolume (interfaceNumber, channelNumber, &ret);
 	FailIf (kIOReturnSuccess != ret, Exit);
-	debug2IOLog ("deviceMin = 0x%X, ", deviceMin);
+	debugIOLog ("deviceMin = 0x%X, ", deviceMin);
 	deviceMax = GetMaxVolume (interfaceNumber, channelNumber, &ret);
 	FailIf (kIOReturnSuccess != ret, Exit);
-	debug2IOLog ("deviceMax = 0x%X\n", deviceMax);
+	debugIOLog ("deviceMax = 0x%X", deviceMax);
 
 	// Having the device say that it does -infinity dB messes up our math, so set the min at -127.9961dB instead.
 	if ((SInt16)0x8000 == deviceMin) {
 		deviceMin = (SInt16)0x8001;
-		debug2IOLog ("deviceMin adjusted to = %d\n", deviceMin);
+		debugIOLog ("deviceMin adjusted to = %d", deviceMin);
 	}
 
 	deviceMinDB = ConvertUSBVolumeTodB (deviceMin);
@@ -104,12 +104,12 @@ bool AppleUSBAudioLevelControl::init (UInt8 theUnitID, UInt8 theInterfaceNumber,
 	resolutionDB = ConvertUSBVolumeTodB (volRes);		// The volume is incremented in units of this many dB, represented as 1/256 dB (eg 256 == 1dB of control)
 
 	offset = -deviceMin;
-	debug2IOLog ("offset = %d\n", offset);
+	debugIOLog ("offset = %d", offset);
 
 	currentValue = (currentValue + offset) / volRes;
 	if (deviceMin < 0 && deviceMax > 0) {
 		deviceMax += volRes;
-		debug2IOLog ("deviceMax adjusted to = 0x%X\n", deviceMax);
+		debugIOLog ("deviceMax adjusted to = 0x%X", deviceMax);
 	}
 	deviceMax = ((deviceMin + offset) + (deviceMax + offset)) / volRes;
 
@@ -148,8 +148,8 @@ bool AppleUSBAudioLevelControl::init (UInt8 theUnitID, UInt8 theInterfaceNumber,
 		channelName = kIOAudioControlChannelNameAll;
 	}
 
-//	debug4IOLog ("min = %d, max = %d, current = %d\n", (deviceMin + offset) - 1, deviceMax, currentValue);
-	debug4IOLog ("min = %d, max = %d, current = %d\n", deviceMin, deviceMax, currentValue);
+//	debugIOLog ("min = %d, max = %d, current = %d", (deviceMin + offset) - 1, deviceMax, currentValue);
+	debugIOLog ("min = %d, max = %d, current = %d", deviceMin, deviceMax, currentValue);
 
 	FailIf (FALSE == super::init (currentValue, deviceMin, deviceMax, deviceMinDB, deviceMaxDB, theChannelNumber, channelName, 0, subType, usage), Exit);
 
@@ -160,12 +160,12 @@ bool AppleUSBAudioLevelControl::init (UInt8 theUnitID, UInt8 theInterfaceNumber,
 	result = TRUE;
 
 Exit:
-	debug8IOLog ("-AppleUSBAudioLevelControl[%p]::init (%d, %d, %d, %d, %p, %p)\n", this, theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, properties);
+	debugIOLog ("-AppleUSBAudioLevelControl[%p]::init (%d, %d, %d, %d, %p, %p)", this, theUnitID, theInterfaceNumber, theControlSelector, theChannelNumber, theUSBDeviceRequest, properties);
 	return result;
 }
 
 void AppleUSBAudioLevelControl::free () {
-    debug2IOLog ("+AppleUSBAudioLevelControl[%p]::free ()\n", this);
+    debugIOLog ("+AppleUSBAudioLevelControl[%p]::free ()", this);
 
     if (setValueThreadCall) {
         thread_call_free (setValueThreadCall);
@@ -173,25 +173,25 @@ void AppleUSBAudioLevelControl::free () {
     }
 
     super::free ();
-    debug2IOLog ("-AppleUSBAudioLevelControl[%p]::free ()\n", this);
+    debugIOLog ("-AppleUSBAudioLevelControl[%p]::free ()", this);
 }
 
 IOReturn AppleUSBAudioLevelControl::performValueChange (OSObject * newValue) {
 	OSNumber *					newValueAsNumber;
 	SInt32						newValueAsSInt32;
 
-    debug3IOLog ("+AppleUSBAudioLevelControl[%p]::performValueChange (%d)\n", this, newValue); 
+    debugIOLog ("+AppleUSBAudioLevelControl[%p]::performValueChange (%d)", this, newValue); 
 
 	newValueAsNumber = OSDynamicCast (OSNumber, newValue);
 	FailIf (NULL == newValueAsNumber, Exit);
 	newValueAsSInt32 = newValueAsNumber->unsigned32BitValue ();
-	debug3IOLog ("++AppleUSBAudioLevelControl[%p]::performValueChange (%ld)\n", this, newValueAsSInt32);
+	debugIOLog ("++AppleUSBAudioLevelControl[%p]::performValueChange (%ld)", this, newValueAsSInt32);
 
     if (NULL != setValueThreadCall) {
         thread_call_enter1 (setValueThreadCall, (thread_call_param_t)newValueAsSInt32);
     }
 
-    debug3IOLog ("-AppleUSBAudioLevelControl[%p]::performValueChange (%d)\n", this, newValueAsSInt32);
+    debugIOLog ("-AppleUSBAudioLevelControl[%p]::performValueChange (%d)", this, newValueAsSInt32);
 
 Exit:
     return kIOReturnSuccess;
@@ -207,7 +207,7 @@ void AppleUSBAudioLevelControl::updateUSBValue (SInt32 newValue) {
 	SInt16						newVolume;
     IOReturn					ret;
 
-    debug3IOLog ("+AppleUSBAudioLevelControl[%p]::updateUSBValue (%d)\n", this, newValue);
+    debugIOLog ("+AppleUSBAudioLevelControl[%p]::updateUSBValue (%d)", this, newValue);
 
 	if (newValue < 0) {
 		newVolume = 0x8000;
@@ -218,9 +218,9 @@ void AppleUSBAudioLevelControl::updateUSBValue (SInt32 newValue) {
 			newVolume = (newValue * volRes) - offset;
 		}
 	}
-	debug2IOLog ("volume value is 0x%X\n", newVolume);
+	debugIOLog ("volume value is 0x%X", newVolume);
     theValue = HostToUSBWord (newVolume);
-	debug2IOLog ("setting volume to 0x%X (little endian)\n", newVolume);
+	debugIOLog ("setting volume to 0x%X (little endian)", newVolume);
 	ret = SetCurVolume (interfaceNumber, channelNumber, theValue);
 
 	if (getSubType () == kIOAudioLevelControlSubTypeLFEVolume) {
@@ -240,7 +240,7 @@ void AppleUSBAudioLevelControl::updateUSBValue (SInt32 newValue) {
 		IORegistryEntry *		engine;
 
 		iSubVolume = NULL;
-		debugIOLog ("Looking for iSub volume control\n");
+		debugIOLog ("Looking for iSub volume control");
 		start = getParentEntry (gIOServicePlane);
 		FailIf (NULL == start, Exit);
 		parent = start->getParentEntry (gIOServicePlane);
@@ -254,7 +254,7 @@ void AppleUSBAudioLevelControl::updateUSBValue (SInt32 newValue) {
 
 		if (NULL != iSubVolume) {
 			newiSubVolume = ((newValue * kiSubMaxVolume) / getMaxValue ()) * kiSubVolumePercent / 100;
-			debugIOLog ("Setting the iSub volume control\n");
+			debugIOLog ("Setting the iSub volume control");
 			iSubVolume->setValue (newiSubVolume);
 			iSubVolume->release ();
 		}
@@ -262,10 +262,10 @@ void AppleUSBAudioLevelControl::updateUSBValue (SInt32 newValue) {
 #endif
 //Exit:
     if (ret != kIOReturnSuccess) {
-        debug4IOLog ("++AppleUSBAudioLevelContol:updateUSBValue () - set current value for %d:%d failed: 0x%X\n", controlSelector, channelNumber, ret);
+        debugIOLog ("++AppleUSBAudioLevelContol:updateUSBValue () - set current value for %d:%d failed: 0x%X", controlSelector, channelNumber, ret);
     }
 
-    debug3IOLog ("-AppleUSBAudioLevelControl[%p]::updateUSBValue (%d)\n", this, newValue);
+    debugIOLog ("-AppleUSBAudioLevelControl[%p]::updateUSBValue (%d)", this, newValue);
 }
 
 SInt16 AppleUSBAudioLevelControl::GetCurVolume (UInt8 interfaceNumber, UInt8 channelNumber, IOReturn * error) {
@@ -371,7 +371,7 @@ Exit:
     return error;
 	
 DeviceInactive:
-	debugIOLog("AppleUSBAudioLevelControl::SetCurVolume ERROR attempt to send a device request to and inactive device\n");
+	debugIOLog("AppleUSBAudioLevelControl::SetCurVolume ERROR attempt to send a device request to and inactive device");
 	error = kIOReturnError;
 	goto Exit;
 }
@@ -381,7 +381,7 @@ void AppleUSBAudioLevelControl::updateValueCallback (void *arg1, void *arg2) {
     SInt32							value;
 	UInt32							subType;
 
-    debug3IOLog ("+AppleUSBAudioLevelControl::updateValueCallback (%p, %p)\n", (UInt32*)arg1, (UInt32*)arg2);
+    debugIOLog ("+AppleUSBAudioLevelControl::updateValueCallback (%p, %p)", (UInt32*)arg1, (UInt32*)arg2);
     levelControl = OSDynamicCast (AppleUSBAudioLevelControl, (OSObject*)arg1);
     value = (SInt32)arg2;
 
@@ -403,7 +403,7 @@ void AppleUSBAudioLevelControl::updateValueCallback (void *arg1, void *arg2) {
 		}
     }
 
-    debug3IOLog ("-AppleUSBAudioLevelControl::updateValueCallback (%p, %p)\n", (UInt32*)arg1, (UInt32*)arg2);
+    debugIOLog ("-AppleUSBAudioLevelControl::updateValueCallback (%p, %p)", (UInt32*)arg1, (UInt32*)arg2);
 }
 
 // This is how the thing is defined in the USB Audio spec (section 5.2.2.4.3.2 for the curious).
@@ -419,7 +419,7 @@ IOFixed AppleUSBAudioLevelControl::ConvertUSBVolumeTodB (SInt16 volume) {
 		dBVolumeFixed = volume * 256;
 	}
 
-	debug3IOLog ("volume = %d, dBVolumeFixed = 0x%X\n", volume, dBVolumeFixed);
+	debugIOLog ("volume = %d, dBVolumeFixed = 0x%X", volume, dBVolumeFixed);
 
 	return dBVolumeFixed;
 }
@@ -491,7 +491,7 @@ void AppleUSBAudioLevelControl::WritePRAMVol (SInt32 leftVol, SInt32 rightVol) {
 
 	platform = OSDynamicCast (IODTPlatformExpert, getPlatform ());
 
-    debug3IOLog ("AppleUSBTrinityAudioDevice::WritePRAMVol leftVol=%lu, rightVol=%lu\n",leftVol,  rightVol);
+    debugIOLog ("AppleUSBTrinityAudioDevice::WritePRAMVol leftVol=%lu, rightVol=%lu",leftVol,  rightVol);
 
     if (NULL != platform) {
 		pramVolume = VolumeToPRAMValue (leftVol, rightVol);
@@ -503,7 +503,7 @@ void AppleUSBAudioLevelControl::WritePRAMVol (SInt32 leftVol, SInt32 rightVol) {
 		if (pramVolume != (curPRAMVol & 0x07)) {
 			// clear bottom 3 bits of volume control byte from PRAM low memory image
 			curPRAMVol = (curPRAMVol & 0xF8) | pramVolume;
-            debug2IOLog ("AppleUSBAudioLevelControl::WritePRAMVol curPRAMVol=0x%x\n", curPRAMVol);
+            debugIOLog ("AppleUSBAudioLevelControl::WritePRAMVol curPRAMVol=0x%x", curPRAMVol);
 
 			// write out the volume control byte to PRAM
 			platform->writeXPRAM ((IOByteCount)kPRamVolumeAddr, &curPRAMVol, (IOByteCount) 1);
