@@ -30,18 +30,18 @@ OSDefineMetaClassAndStructors (AppleiSubEngine, super)
 void AppleiSubEngine::closeiSub (IOService * forClient) {
 	IOReturn				result;
 
-	debug3IOLog ("+AppleiSubEngine[%p]::closeiSub (%p)\n", this, forClient);
+	debugIOLog ("+AppleiSubEngine[%p]::closeiSub (%p)", this, forClient);
 
 	if (forClient == audioEngine) {
 		if ((NULL != muteControl || NULL != iSubVolumeControl) && NULL != audioEngine) {
-			debugIOLog ("Removing iSub audio controls\n");
+			debugIOLog ("Removing iSub audio controls");
 	
 			if (NULL != iSubVolumeControl) {
 				result = audioEngine->removeDefaultAudioControl (iSubVolumeControl);
 				iSubVolumeControl->release ();
 				iSubVolumeControl = NULL;
 				#if DEBUGLOG
-				if (kIOReturnSuccess != result) IOLog ("Error 0x%x removing left iSub control\n", result);
+				if (kIOReturnSuccess != result) debugIOLog ("Error 0x%x removing left iSub control", result);
 				#endif
 			}
 	
@@ -51,7 +51,7 @@ void AppleiSubEngine::closeiSub (IOService * forClient) {
 				muteControl->release ();
 				muteControl = NULL;
 				#if DEBUGLOG
-				if (kIOReturnSuccess != result) IOLog ("Error 0x%x removing mute iSub control\n", result);
+				if (kIOReturnSuccess != result) debugIOLog ("Error 0x%x removing mute iSub control", result);
 				#endif
 			}
 	
@@ -60,22 +60,22 @@ void AppleiSubEngine::closeiSub (IOService * forClient) {
 			audioEngine = NULL;
 #if DEBUGLOG
 		} else {
-			if (NULL == muteControl) {IOLog ("NULL == muteControl\n");}
-			if (NULL == iSubVolumeControl) {IOLog ("NULL == iSubVolumeControl\n");}
-			if (NULL == audioEngine) {IOLog ("NULL == audioEngine\n");}
+			if (NULL == muteControl) {debugIOLog ("NULL == muteControl");}
+			if (NULL == iSubVolumeControl) {debugIOLog ("NULL == iSubVolumeControl");}
+			if (NULL == audioEngine) {debugIOLog ("NULL == audioEngine");}
 #endif
 		}
 	} else {
-		debugIOLog ("the wrong client tried to close us\n");
+		debugIOLog ("the wrong client tried to close us");
 	}
 
-	debug3IOLog ("-AppleiSubEngine[%p]::closeiSub (%p)\n", this, forClient);
+	debugIOLog ("-AppleiSubEngine[%p]::closeiSub (%p)", this, forClient);
 }
 
 void AppleiSubEngine::free (void) {
 	UInt32							frameIndex;
 
-	debug2IOLog ("+AppleiSubEngine[%p]::free ()\n", this);
+	debugIOLog ("+AppleiSubEngine[%p]::free ()", this);
 
 	if (NULL != thePipe) {
 		thePipe->release ();
@@ -101,7 +101,7 @@ void AppleiSubEngine::free (void) {
 
 	super::free ();
 
-	debug2IOLog ("-AppleiSubEngine[%p]::free ()\n", this);
+	debugIOLog ("-AppleiSubEngine[%p]::free ()", this);
 	return;
 }
 
@@ -162,14 +162,14 @@ bool AppleiSubEngine::openiSub (IOService * forClient, iSubRequestCloseRoutine t
 	resultCode = TRUE;
 
 Exit:
-	debug4IOLog ("-AppleiSubEngine[%p]::handleOpen (%p, 0x%lx, %p) = %d\n", this, forClient, resultCode);
+	debugIOLog ("-AppleiSubEngine[%p]::handleOpen (%p, 0x%lx, %p) = %d", this, forClient, resultCode);
 	return resultCode;
 }
 
 bool AppleiSubEngine::init (OSDictionary * properties) {
 	Boolean							resultCode;
 
-	debug3IOLog ("+AppleiSubEngine[%p]::init (%p)\n", this, properties);
+	debugIOLog ("+AppleiSubEngine[%p]::init (%p)", this, properties);
 
 	resultCode = FALSE;
 	terminatingDriver = FALSE;
@@ -185,7 +185,7 @@ bool AppleiSubEngine::init (OSDictionary * properties) {
 	mFormat.outputSampleRate = kDefaultOutputSampleRate;		
 
 Exit:
-	debug4IOLog ("-AppleiSubEngine[%p]::init (%p) = %d\n", this, properties, resultCode);
+	debugIOLog ("-AppleiSubEngine[%p]::init (%p) = %d", this, properties, resultCode);
 	return resultCode;
 }
 
@@ -202,7 +202,7 @@ bool AppleiSubEngine::start (IOService * provider) {
 		{kIOPMPowerStateVersion1, kIOPMDeviceUsable, kIOPMPowerOn, kIOPMPowerOn, 0, 0, 0, 0, 0, 0, 0, 0}
 	};
 
-	debug3IOLog ("+AppleiSubEngine[%p]::start (%p)\n", this, provider);
+	debugIOLog ("+AppleiSubEngine[%p]::start (%p)", this, provider);
 
 	resultBool = FALSE;
 	FailIf (FALSE == super::start (provider), Exit);
@@ -211,7 +211,7 @@ bool AppleiSubEngine::start (IOService * provider) {
 	FailIf (NULL == streamInterface, Exit);
 
 	ourInterfaceNumber = streamInterface->GetInterfaceNumber ();
-	debug2IOLog ("AppleiSubEngine->ourInterfaceNumber = %d\n", ourInterfaceNumber);
+	debugIOLog ("AppleiSubEngine->ourInterfaceNumber = %d", ourInterfaceNumber);
 	// aml 1.18.02 replaced constant with member
 	alternateInterfaceID = mFormat.altInterface;		
 
@@ -226,15 +226,15 @@ bool AppleiSubEngine::start (IOService * provider) {
 	// aml 2.13.02 replaced kInputSampleRate with mOutputSampleRate
 	// aml 2.13.02 added num channels and bit depth constants, instead of '4'
 	frameListSize = CalculateNumSamplesPerBuffer (mFormat.outputSampleRate, NUM_ISUB_FRAMES_PER_LIST) * mFormat.numChannels * mFormat.bytesPerSample;
-	debug4IOLog ("format = %ldHz, %ld channels, %ld bits\n", mFormat.outputSampleRate, mFormat.numChannels, mFormat.bytesPerSample * 8);
+	debugIOLog ("format = %ldHz, %ld channels, %ld bits", mFormat.outputSampleRate, mFormat.numChannels, mFormat.bytesPerSample * 8);
 #if AML_DEBUGLOG
-	IOLog ("AppleiSubEngine::handleOpen: frameListSize = %d\n", frameListSize);
+	debugIOLog ("AppleiSubEngine::handleOpen: frameListSize = %d", frameListSize);
 #endif
-	debug2IOLog ("frameListSize = %d\n", frameListSize);
+	debugIOLog ("frameListSize = %d", frameListSize);
 	// aml 2.13.02 replaced kInputSampleRate with mOutputSampleRate
 	// aml 2.13.02 added num channels and bit depth members, instead of '4'
 	bufferSize = CalculateNumSamplesPerBuffer (mFormat.outputSampleRate, NUM_ISUB_FRAMES_PER_LIST, NUM_ISUB_FRAME_LISTS) * mFormat.numChannels * mFormat.bytesPerSample;
-	debug2IOLog ("bufferSize = %d\n", bufferSize);
+	debugIOLog ("bufferSize = %d", bufferSize);
 	sampleBuffer = IOMallocAligned (bufferSize, PAGE_SIZE);
 	FailIf (NULL == sampleBuffer, Exit);
 	// aml 2.13.02 changed from clearing by longs to words
@@ -246,7 +246,7 @@ bool AppleiSubEngine::start (IOService * provider) {
 
 	FailIf (kIOReturnSuccess != PrepareFrameLists (frameListSize), Exit);
 //	FailIf (TRUE == streamOpened, Exit);
-//	IOLog ("after TRUE == streamOpened\n");
+//	debugIOLog ("after TRUE == streamOpened");
 	shouldCloseStream = FALSE;
 	FailIf (FALSE == streamInterface->open (this), Exit);
 	streamOpened = TRUE;
@@ -282,7 +282,7 @@ bool AppleiSubEngine::start (IOService * provider) {
 		FailIf (kIOReturnSuccess != resultIOReturn, Exit);
 		numQueued++;
 	}
-	debug2IOLog ("writeFrameList resultIOReturn = 0x%lx\n", resultIOReturn);
+	debugIOLog ("writeFrameList resultIOReturn = 0x%lx", resultIOReturn);
 
 	// Find control interface on iSub device
 	findRequest.bInterfaceClass = 1;
@@ -296,24 +296,24 @@ bool AppleiSubEngine::start (IOService * provider) {
 	resultBool = TRUE;
 
 Exit:
-	debug4IOLog ("-AppleiSubEngine[%p]::start (%p) = %d\n", this, provider, resultBool);
+	debugIOLog ("-AppleiSubEngine[%p]::start (%p) = %d", this, provider, resultBool);
 	return resultBool;
 }
 
 void AppleiSubEngine::stop (IOService *provider) {
-	debugIOLog("+AppleiSubEngine::stop\n");
+	debugIOLog("+AppleiSubEngine::stop");
 
 	PMstop();
 
 	super::stop(provider);
 
-	debugIOLog("-AppleiSubEngine::stop\n");
+	debugIOLog("-AppleiSubEngine::stop");
 }
 
 bool AppleiSubEngine::willTerminate (IOService * provider, IOOptionBits options) {
 	bool					resultCode;
 
-	debug5IOLog ("+AppleiSubEngine[%p]::willTerminate (%p, 0x%x) rc =\n", this, provider, options, getRetainCount ());
+	debugIOLog ("+AppleiSubEngine[%p]::willTerminate (%p, 0x%x) rc =", this, provider, options, getRetainCount ());
 
 	terminatingDriver = TRUE;
 
@@ -324,7 +324,7 @@ bool AppleiSubEngine::willTerminate (IOService * provider, IOOptionBits options)
 	if (FALSE == iSubUSBRunning) {
 		// close our stream interface and go away
 		if ((streamInterface != NULL) && (streamInterface == provider)) {
-			debugIOLog ("willTerminate closing iSub down\n");
+			debugIOLog ("willTerminate closing iSub down");
 			if (NULL != thePipe) {
 				thePipe->release ();
 				thePipe = NULL;
@@ -338,27 +338,27 @@ bool AppleiSubEngine::willTerminate (IOService * provider, IOOptionBits options)
 
 	resultCode = super::willTerminate (provider, options);
 
-	debug6IOLog ("-AppleiSubEngine[%p]::willTerminate (%p, 0x%x) = %d, rc=%d\n", this, provider, options, resultCode, getRetainCount ());
+	debugIOLog ("-AppleiSubEngine[%p]::willTerminate (%p, 0x%x) = %d, rc=%d", this, provider, options, resultCode, getRetainCount ());
 	return resultCode;
 }
 
 IOReturn AppleiSubEngine::setPowerState (unsigned long powerStateOrdinal, IOService *device) {
 	IOReturn					result;
 
-	debug4IOLog("AppleiSubEngine[%p]::setPowerState (%lu, %p)\n", this, powerStateOrdinal, device);
+	debugIOLog("AppleiSubEngine[%p]::setPowerState (%lu, %p)", this, powerStateOrdinal, device);
 
 	result = kIOReturnError;
 
 	if (device == this) {
 		switch (powerStateOrdinal) {
 			case 0:		// Power off state
-				debugIOLog ("sleeping...\n");
+				debugIOLog ("sleeping...");
 				sleeping = TRUE;
 				StopiSub ();
 				result = IOPMNoErr;
 				break;
 			case 1:		// Power on state
-				debugIOLog ("waking...\n");
+				debugIOLog ("waking...");
 				sleeping = FALSE;	
 				result = IOPMNoErr;
 				break;
@@ -410,13 +410,13 @@ void AppleiSubEngine::CalculateSamplesPerFrame (UInt32 sampleRate, UInt16 * aver
 IOReturn AppleiSubEngine::deviceRequest (IOUSBDevRequest * request, AppleiSubEngine * self, IOUSBCompletion * completion) {
 	IOReturn						result;
 
-	debug4IOLog ("+AppleiSubEngine[%p]::deviceRequest (%p, %p)\n", self, request, completion);
+	debugIOLog ("+AppleiSubEngine[%p]::deviceRequest (%p, %p)", self, request, completion);
 	result = kIOReturnSuccess;
 	if (self->streamInterface && request && (FALSE == self->terminatingDriver)) {
 		result = self->streamInterface->DeviceRequest (request, completion);
 	}
 
-	debug4IOLog ("-AppleiSubEngine[%p]::deviceRequest (%p, %p)\n", self, request, completion);
+	debugIOLog ("-AppleiSubEngine[%p]::deviceRequest (%p, %p)", self, request, completion);
 	return result;
 }
 
@@ -458,7 +458,7 @@ IOReturn AppleiSubEngine::StartiSub (void) {
 	UInt16							numQueued = 0;	// aml this was unititialized and the for loop below never ran sometimes!
     IOReturn						resultCode;
 
-	debug2IOLog ("+AppleiSubEngine[%p]::StartiSub ()\n", this);
+	debugIOLog ("+AppleiSubEngine[%p]::StartiSub ()", this);
 
 	FailWithAction (TRUE == sleeping, resultCode = kIOReturnOffline, Exit);
 	resultCode = kIOReturnError;
@@ -504,18 +504,18 @@ IOReturn AppleiSubEngine::StartiSub (void) {
 	}
 
 Exit:
-	debug3IOLog ("-AppleiSubEngine[%p]::StartiSub (), result = %d\n", this, resultCode);
+	debugIOLog ("-AppleiSubEngine[%p]::StartiSub (), result = %d", this, resultCode);
 
 	return resultCode;
 }
 
 IOReturn AppleiSubEngine::StopiSub (void) {
 
-	debug2IOLog ("+AppleiSubEngine[%p]::StopiSub ()\n", this);
+	debugIOLog ("+AppleiSubEngine[%p]::StopiSub ()", this);
 
 	iSubRunning = FALSE;
 
-	debug2IOLog ("-AppleiSubEngine[%p]::StopiSub ()\n", this);
+	debugIOLog ("-AppleiSubEngine[%p]::StopiSub ()", this);
 
 	return kIOReturnSuccess;
 }
@@ -563,7 +563,7 @@ IOReturn AppleiSubEngine::WriteFrameList (UInt32 frameListNum) {
 
 	if (result != kIOReturnSuccess) {
 		if (streamInterface) {
-			debug6IOLog ("++AppleiSubEngine[%p]::WriteFrameList (%d) - error writing to pipe at frame %lu - current = %lu: 0x%x\n", this, frameListNum, (UInt32)theFirstFrame, (UInt32)streamInterface->GetDevice()->GetBus()->GetFrameNumber(), result);
+			debugIOLog ("++AppleiSubEngine[%p]::WriteFrameList (%d) - error writing to pipe at frame %lu - current = %lu: 0x%x", this, frameListNum, (UInt32)theFirstFrame, (UInt32)streamInterface->GetDevice()->GetBus()->GetFrameNumber(), result);
 		}
 		iSubUSBRunning = FALSE;
 	} else {
@@ -586,16 +586,14 @@ void AppleiSubEngine::WriteHandler (void * object, void * buffer, IOReturn resul
 	FailIf (TRUE == self->sleeping, Exit);
 
 	if (result != kIOReturnSuccess) {
-#if DEBUGLOG
-		IOLog ("++AppleiSubEngine::WriteHandler () - error 0x%x\n", result);
-#endif
+		debugIOLog ("++AppleiSubEngine::WriteHandler () - error 0x%x", result);
 		FailIf (NULL == self->streamInterface, Exit);
 		currentUSBFrame = self->streamInterface->GetDevice()->GetBus()->GetFrameNumber ();
 		switch (result) {
 #if ABORT_PIPE_ON_START
 			case kIOReturnAborted:
 #if AML_DEBUGLOG
-				IOLog ("AppleiSubEngine::WriteHandler() aborted.\n");
+				debugIOLog ("AppleiSubEngine::WriteHandler() aborted.");
 #endif
 				goto Exit;			// do nothing
 				break;
@@ -608,9 +606,7 @@ void AppleiSubEngine::WriteHandler (void * object, void * buffer, IOReturn resul
 				// skip ahead and see if that helps
 				if (self->theFirstFrame <= currentUSBFrame) {
 					self->theFirstFrame = currentUSBFrame + kMinimumiSubFrameOffset;
-#if DEBUGLOG
-					IOLog ("+++AppleiSubEngine::skipping ahead to frame %ld\n", self->theFirstFrame);
-#endif
+					debugIOLog ("+++AppleiSubEngine::skipping ahead to frame %ld", self->theFirstFrame);
 				}
 				break;
 		}
@@ -661,9 +657,9 @@ void AppleiSubEngine::WriteHandler (void * object, void * buffer, IOReturn resul
 #if DEBUGLOG
 	nanos_del = nanos_del / (1000);
 	if (nanos_del > 11000) {
-		IOLog ("iSubEngine::WriteHandler - delta = %ld microseconds\n", (UInt32)(nanos_del));
+		debugIOLog ("iSubEngine::WriteHandler - delta = %ld microseconds", (UInt32)(nanos_del));
 	} else 	if (nanos_del < 9000) {
-		IOLog ("iSubEngine::WriteHandler - delta = %ld microseconds\n", (UInt32)(nanos_del));
+		debugIOLog ("iSubEngine::WriteHandler - delta = %ld microseconds", (UInt32)(nanos_del));
 	}
 #endif
 
@@ -674,14 +670,10 @@ void AppleiSubEngine::WriteHandler (void * object, void * buffer, IOReturn resul
 	
 Exit:
 	if (TRUE == self->shouldCloseStream) {
-		#if DEBUGLOG
-		IOLog ("++AppleiSubEngine[%p]::WriteHandler () - stopping: %d\n", self, self->numUSBFrameListsNotOutstanding);
-		#endif
+		debugIOLog ("++AppleiSubEngine[%p]::WriteHandler () - stopping: %d", self, self->numUSBFrameListsNotOutstanding);
 		self->numUSBFrameListsNotOutstanding++;
 		if (self->numUSBFrameListsNotOutstanding == NUM_ISUB_FRAME_LISTS_TO_QUEUE) {
-			#if DEBUGLOG
-			IOLog ("iSub last write completed, closing streamInterface\n");
-			#endif
+			debugIOLog ("iSub last write completed, closing streamInterface");
 			if (NULL != self->thePipe) {
 				self->thePipe->release ();
 				self->thePipe = NULL;
