@@ -70,9 +70,9 @@ void USBAudioConfigObject::DumpConfigMemoryToIOLog (void) {
 	while (*descriptorPtr != 0) {
 		length = *descriptorPtr;
 		for (descriptorIndex = 0; descriptorIndex < length; descriptorIndex++) {
-			debug2IOLog ("%2x ", *descriptorPtr++);
+			debugIOLog ("%2x ", *descriptorPtr++);
 		}
-		debugIOLog ("\n");
+		debugIOLog ("");
 	}
 #endif
 }
@@ -87,7 +87,7 @@ bool USBAudioConfigObject::init (const IOUSBConfigurationDescriptor * newConfigu
 
 	theControlInterfaceNum = controlInterfaceNum;
 
-    debug2IOLog ("allocating %d bytes for config descriptor\n", USBToHostWord (newConfigurationDescriptor->wTotalLength));
+    debugIOLog ("allocating %d bytes for config descriptor", USBToHostWord (newConfigurationDescriptor->wTotalLength));
     theConfigurationDescriptorPtr = (IOUSBConfigurationDescriptor *)IOMalloc (USBToHostWord (newConfigurationDescriptor->wTotalLength) + 1);
     FailIf (NULL == theConfigurationDescriptorPtr, Exit);
 
@@ -289,7 +289,7 @@ void USBAudioConfigObject::GetControlledStreamNumbers (UInt8 **controledStreams,
 	if (NULL != theControls) {
 		thisControl = OSDynamicCast (USBAudioControlObject, theControls->getObject (0));
 	} else {
-		debugIOLog ("couldn't get the control object\n");
+		debugIOLog ("couldn't get the control object");
 	}
 
 	if (thisControl) {
@@ -406,22 +406,22 @@ UInt8 USBAudioConfigObject::GetIsocEndpointDirection (UInt8 interfaceNum, UInt8
 	index = 0;
 	numEndpoints = 0;
     thisStream = GetStreamObject (interfaceNum, altInterfaceNum);
-	debug4IOLog ("GetIsocEndpointDirection (%d, %d), thisStream = %p\n", interfaceNum, altInterfaceNum, thisStream);
+	debugIOLog ("GetIsocEndpointDirection (%d, %d), thisStream = %p", interfaceNum, altInterfaceNum, thisStream);
     thisControl = GetControlObject (theControlInterfaceNum, 0);
-	debug4IOLog ("GetIsocEndpointDirection (%d, %d), thisControl = %p\n", interfaceNum, altInterfaceNum, thisControl);
+	debugIOLog ("GetIsocEndpointDirection (%d, %d), thisControl = %p", interfaceNum, altInterfaceNum, thisControl);
 	if (NULL != thisStream && NULL != thisControl) {
 		terminalLink = thisStream->GetTerminalLink ();		// returns the unitID of the terminal the endpoint goes with
-		debug4IOLog ("GetIsocEndpointDirection (%d, %d), terminalLink = %d\n", interfaceNum, altInterfaceNum, terminalLink);
+		debugIOLog ("GetIsocEndpointDirection (%d, %d), terminalLink = %d", interfaceNum, altInterfaceNum, terminalLink);
 		if (0 != terminalLink) {
 			numOutputs = thisControl->GetNumOutputTerminals ();
-			debug4IOLog ("GetIsocEndpointDirection (%d, %d), numOutputs = %d\n", interfaceNum, altInterfaceNum, numOutputs);
+			debugIOLog ("GetIsocEndpointDirection (%d, %d), numOutputs = %d", interfaceNum, altInterfaceNum, numOutputs);
 			while (0xFF == direction && index < numOutputs) {
 				terminalID = thisControl->GetIndexedOutputTerminalID (index);
-				debug4IOLog ("GetIsocEndpointDirection (%d, %d), terminalID = %d\n", interfaceNum, altInterfaceNum, terminalID);
+				debugIOLog ("GetIsocEndpointDirection (%d, %d), terminalID = %d", interfaceNum, altInterfaceNum, terminalID);
 				if (terminalID == terminalLink) {
 					direction = kUSBIn;
 					numEndpoints = numOutputs;
-					debug5IOLog ("GetIsocEndpointDirection (%d, %d), found an output terminal (#%d) at index %d\n", interfaceNum, altInterfaceNum, terminalID, index);
+					debugIOLog ("GetIsocEndpointDirection (%d, %d), found an output terminal (#%d) at index %d", interfaceNum, altInterfaceNum, terminalID, index);
 				} else {
 					index++;
 				}
@@ -429,16 +429,16 @@ UInt8 USBAudioConfigObject::GetIsocEndpointDirection (UInt8 interfaceNum, UInt8
 
 			if (0xFF == direction) {
 				numInputs = thisControl->GetNumInputTerminals ();
-				debug3IOLog ("GetIsocEndpointDirection (%d, %d), Didn't find an output terminal, checking for an input terminal\n", interfaceNum, altInterfaceNum);
-				debug4IOLog ("GetIsocEndpointDirection (%d, %d), numInputs = %d\n", interfaceNum, altInterfaceNum, numInputs);
+				debugIOLog ("GetIsocEndpointDirection (%d, %d), Didn't find an output terminal, checking for an input terminal", interfaceNum, altInterfaceNum);
+				debugIOLog ("GetIsocEndpointDirection (%d, %d), numInputs = %d", interfaceNum, altInterfaceNum, numInputs);
 				index = 0;
 				while (0xFF == direction && index < numInputs) {
 					terminalID = thisControl->GetIndexedInputTerminalID (index);
-					debug4IOLog ("GetIsocEndpointDirection, terminalID = %d\n", interfaceNum, altInterfaceNum, terminalID);
+					debugIOLog ("GetIsocEndpointDirection, terminalID = %d", interfaceNum, altInterfaceNum, terminalID);
 					if (terminalID == terminalLink) {
 						direction = kUSBOut;
 						numEndpoints = numInputs;
-						debug5IOLog ("GetIsocEndpointDirection (%d, %d), found an input terminal (#%d) at index %d\n", interfaceNum, altInterfaceNum, terminalID, index);
+						debugIOLog ("GetIsocEndpointDirection (%d, %d), found an input terminal (#%d) at index %d", interfaceNum, altInterfaceNum, terminalID, index);
 					} else {
 						index++;
 					}
@@ -456,7 +456,7 @@ UInt8 USBAudioConfigObject::GetIsocEndpointDirection (UInt8 interfaceNum, UInt8
 		}
 	}
 
-	debug4IOLog ("GetIsocEndpointDirection (%d, %d), endpointDirection = %d\n", interfaceNum, altInterfaceNum, endpointDirection);
+	debugIOLog ("GetIsocEndpointDirection (%d, %d), endpointDirection = %d", interfaceNum, altInterfaceNum, endpointDirection);
     return endpointDirection;
 }
 
@@ -635,7 +635,7 @@ UInt8 USBAudioConfigObject::GetNumAltStreamInterfaces (UInt8 interfaceNum) {
 
     numAltInterfaces = 0;
 	if (NULL != theStreams) {
-		debug2IOLog ("USBAudioConfigObject::GetNumAltInterfaces %d = theStreams->getCount ()\n", theStreams->getCount ());
+		debugIOLog ("USBAudioConfigObject::GetNumAltInterfaces %d = theStreams->getCount ()", theStreams->getCount ());
 		for (indx = 0; indx < theStreams->getCount (); indx++) {
 			thisStream = OSDynamicCast (USBAudioStreamObject, theStreams->getObject (indx));
 			if (thisStream && thisStream->GetInterfaceNum () == interfaceNum) {
@@ -716,7 +716,7 @@ UInt8 USBAudioConfigObject::GetNumStreamInterfaces (void) {
     numInterfaces = 0;
     interfaceNum = 0;
 	if (NULL != theStreams) {
-		debug2IOLog ("USBAudioConfigObject::GetNumInterfaces %d = theStreams->getCount ()\n", theStreams->getCount ());
+		debugIOLog ("USBAudioConfigObject::GetNumInterfaces %d = theStreams->getCount ()", theStreams->getCount ());
 		for (indx = 0; indx < theStreams->getCount (); indx++) {
 			thisStream = OSDynamicCast (USBAudioStreamObject, theStreams->getObject (indx));
 			if (thisStream && thisStream->GetInterfaceNum () != interfaceNum) {
@@ -907,7 +907,7 @@ Boolean USBAudioConfigObject::VerifySampleRateIsSupported (UInt8 interfaceNum, U
 			result = TRUE;
 		}
 	} else {
-		debugIOLog ("!!!!There aren't any sample rates!!!!\n");
+		debugIOLog ("!!!!There aren't any sample rates!!!!");
 	}
 
 	return result;
@@ -993,13 +993,13 @@ void USBAudioConfigObject::ParseConfigurationDescriptor (void) {
 	foundStreamInterface = FALSE;
     while (theInterfacePtr && 0 != theInterfacePtr->bLength) {
         if (INTERFACE == ((ACInterfaceDescriptorPtr)theInterfacePtr)->bDescriptorType) {
-			debugIOLog ("in INTERFACE in ParseConfigurationDescriptor\n");
+			debugIOLog ("in INTERFACE in ParseConfigurationDescriptor");
 			thisInterfaceNumber = ((ACInterfaceDescriptorPtr)theInterfacePtr)->bInterfaceNumber;
 			theInterfacePtr = ParseInterfaceDescriptor (theInterfacePtr, &interfaceClass, &interfaceSubClass);
 
-			debug3IOLog ("theControlInterfaceNum = %d, thisInterfaceNumber = %d\n", theControlInterfaceNum, thisInterfaceNumber);
+			debugIOLog ("theControlInterfaceNum = %d, thisInterfaceNumber = %d", theControlInterfaceNum, thisInterfaceNumber);
 			if (AUDIOCONTROL == interfaceSubClass && theControlInterfaceNum == thisInterfaceNumber) {
-				debugIOLog ("found a AUDIOCONTROL CS_INTERFACE \n");
+				debugIOLog ("found a AUDIOCONTROL CS_INTERFACE ");
 				if (NULL != theControls) {
 					theControlObject = OSDynamicCast (USBAudioControlObject, theControls->getLastObject ());
 				}
@@ -1008,11 +1008,11 @@ void USBAudioConfigObject::ParseConfigurationDescriptor (void) {
 				GetControlledStreamNumbers (&streamInterfaceNumbers, &numStreamInterfaces);
 				haveControlInterface = TRUE;
 			} else if (haveControlInterface && AUDIOSTREAMING == interfaceSubClass) {
-				debugIOLog ("in CS_INTERFACE in ParseConfigurationDescriptor\n");
+				debugIOLog ("in CS_INTERFACE in ParseConfigurationDescriptor");
 				for (index = 0; index < numStreamInterfaces; index++) {
-					debug3IOLog ("comparing thisInterfaceNum = %d with %d\n", thisInterfaceNumber, streamInterfaceNumbers[index]);
+					debugIOLog ("comparing thisInterfaceNum = %d with %d", thisInterfaceNumber, streamInterfaceNumbers[index]);
 					if (thisInterfaceNumber == streamInterfaceNumbers[index]) {
-						debugIOLog ("found a AUDIOSTREAMING CS_INTERFACE \n");
+						debugIOLog ("found a AUDIOSTREAMING CS_INTERFACE ");
 						if (NULL != theStreams) {
 							theStreamObject = OSDynamicCast (USBAudioStreamObject, theStreams->getLastObject ());
 						}
@@ -1030,7 +1030,7 @@ void USBAudioConfigObject::ParseConfigurationDescriptor (void) {
 					}
 				}
 			} else if (MIDISTREAMING == interfaceSubClass) {
-				debug2IOLog ("MIDI, jumping forward %d bytes\n", theInterfacePtr->bLength);
+				debugIOLog ("MIDI, jumping forward %d bytes", theInterfacePtr->bLength);
 				for (index = 0; index < numStreamInterfaces; index++) {
 					if (thisInterfaceNumber == streamInterfaceNumbers[index]) {
 						break;
@@ -1038,15 +1038,15 @@ void USBAudioConfigObject::ParseConfigurationDescriptor (void) {
 				}
 				theInterfacePtr = (USBInterfaceDescriptorPtr)((UInt8 *)theInterfacePtr + theInterfacePtr->bLength);
 			} else if (AUDIOCONTROL == interfaceSubClass) {
-				debugIOLog ("Found a control interface that we don't care about\n");
-				debug2IOLog ("jumping forward %d bytes\n", ((((ACInterfaceHeaderDescriptorPtr)theInterfacePtr)->wTotalLength[1] << 8) | (((ACInterfaceHeaderDescriptorPtr)theInterfacePtr)->wTotalLength[0])));
+				debugIOLog ("Found a control interface that we don't care about");
+				debugIOLog ("jumping forward %d bytes", ((((ACInterfaceHeaderDescriptorPtr)theInterfacePtr)->wTotalLength[1] << 8) | (((ACInterfaceHeaderDescriptorPtr)theInterfacePtr)->wTotalLength[0])));
 				theInterfacePtr = (USBInterfaceDescriptorPtr)((UInt8 *)theInterfacePtr + ((((ACInterfaceHeaderDescriptorPtr)theInterfacePtr)->wTotalLength[1] << 8) | (((ACInterfaceHeaderDescriptorPtr)theInterfacePtr)->wTotalLength[0])));
 			} else {
-				debug2IOLog ("Unknown, jumping forward %d bytes\n", theInterfacePtr->bLength);
+				debugIOLog ("Unknown, jumping forward %d bytes", theInterfacePtr->bLength);
 				theInterfacePtr = (USBInterfaceDescriptorPtr)((UInt8 *)theInterfacePtr + theInterfacePtr->bLength);
 			}
 		} else {
-			debug2IOLog ("in default in ParseConfigurationDescriptor, jumping forward %d bytes\n", theInterfacePtr->bLength);
+			debugIOLog ("in default in ParseConfigurationDescriptor, jumping forward %d bytes", theInterfacePtr->bLength);
 			theInterfacePtr = (USBInterfaceDescriptorPtr)((UInt8 *)theInterfacePtr + theInterfacePtr->bLength);
         }
     }
@@ -1063,7 +1063,7 @@ USBInterfaceDescriptorPtr USBAudioConfigObject::ParseInterfaceDescriptor (USBInt
 	USBAudioControlObject *				theControlObject;
 	USBAudioStreamObject *				theStreamObject;
 
-	debugIOLog ("in ParseInterfaceDescriptor\n");
+	debugIOLog ("in ParseInterfaceDescriptor");
 
 	FailIf (NULL == theInterfacePtr, Exit);
 	FailIf (0 == theInterfacePtr->bLength, Exit);
@@ -1074,7 +1074,7 @@ USBInterfaceDescriptorPtr USBAudioConfigObject::ParseInterfaceDescriptor (USBInt
 		*interfaceSubClass = theInterfacePtr->bInterfaceSubClass;
 
 	if (AUDIOCONTROL == theInterfacePtr->bInterfaceSubClass) {
-		debugIOLog ("found a AUDIOCONTROL interface\n");
+		debugIOLog ("found a AUDIOCONTROL interface");
 		if (theControlInterfaceNum == theInterfacePtr->bDescriptorSubtype) {
 			theControlObject = USBAudioControlObject::create ();
 
@@ -1096,7 +1096,7 @@ USBInterfaceDescriptorPtr USBAudioConfigObject::ParseInterfaceDescriptor (USBInt
 			theControlObject->release ();
 		}
 	} else if (AUDIOSTREAMING == theInterfacePtr->bInterfaceSubClass) {
-		debugIOLog ("found a AUDIOSTREAMING interface\n");
+		debugIOLog ("found a AUDIOSTREAMING interface");
 		theStreamObject = USBAudioStreamObject::create ();
 
 		FailIf (NULL == theStreamObject, Exit);
@@ -1595,7 +1595,7 @@ USBInterfaceDescriptorPtr USBAudioControlObject::ParseACInterfaceDescriptor (USB
 	USBSelectorUnitObject *		selectorUnit;
 	UInt8						index;
 
-	debug3IOLog ("+USBAudioControlObject::ParseACInterfaceDescriptor (%p, %d)\n", theInterfacePtr, currentInterface);
+	debugIOLog ("+USBAudioControlObject::ParseACInterfaceDescriptor (%p, %d)", theInterfacePtr, currentInterface);
 
     FailIf (NULL == theInterfacePtr, Exit);
     FailIf (0 == theInterfacePtr->bLength, Exit);
@@ -1604,23 +1604,23 @@ USBInterfaceDescriptorPtr USBAudioControlObject::ParseACInterfaceDescriptor (USB
     while (theInterfacePtr->bLength && CS_INTERFACE == theInterfacePtr->bDescriptorType) {
         switch (theInterfacePtr->bDescriptorSubtype) {
             case HEADER:
-                debugIOLog ("in HEADER in ParseACInterfaceDescriptor\n");
+                debugIOLog ("in HEADER in ParseACInterfaceDescriptor");
                 adcVersion = USBToHostWord (((ACInterfaceHeaderDescriptorPtr)theInterfacePtr)->bcdADC[0]);
 				if (adcVersion != 0x0100) {
 				}
 				// !!!Need to check the adcVersion to make sure that it's 0x0100 or else we don't know how to parse this descriptor!!!
                 numStreamInterfaces = ((ACInterfaceHeaderDescriptorPtr)theInterfacePtr)->bInCollection;
-				debug2IOLog ("numStreamInterfaces = %d\n", numStreamInterfaces);
+				debugIOLog ("numStreamInterfaces = %d", numStreamInterfaces);
 				streamInterfaceNumbers = (UInt8 *)IOMalloc (numStreamInterfaces);
 				memcpy (streamInterfaceNumbers, ((ACInterfaceHeaderDescriptorPtr)theInterfacePtr)->baInterfaceNr, numStreamInterfaces);
 				debugIOLog ("they are: ");
 				for (index = 0; index < numStreamInterfaces; index++) {
-					debug2IOLog ("%d, ", streamInterfaceNumbers[index]);
+					debugIOLog ("%d, ", streamInterfaceNumbers[index]);
 				}
-				debugIOLog ("\n");
+				debugIOLog ("");
                 break;
             case INPUT_TERMINAL:
-                debugIOLog ("in INPUT_TERMINAL in ParseACInterfaceDescriptor\n");
+                debugIOLog ("in INPUT_TERMINAL in ParseACInterfaceDescriptor");
 				inputTerminal = new USBInputTerminalObject;
 				FailIf (NULL == inputTerminal, Exit);
                 inputTerminal->SetUnitID (((ACInputTerminalDescriptorPtr)theInterfacePtr)->bTerminalID);
@@ -1639,7 +1639,7 @@ USBInterfaceDescriptorPtr USBAudioControlObject::ParseACInterfaceDescriptor (USB
 				inputTerminal->release ();
                 break;
             case OUTPUT_TERMINAL:
-                debugIOLog ("in OUTPUT_TERMINAL in ParseACInterfaceDescriptor\n");
+                debugIOLog ("in OUTPUT_TERMINAL in ParseACInterfaceDescriptor");
 				outputTerminal = new USBOutputTerminalObject;
 				FailIf (NULL == outputTerminal, Exit);
                 outputTerminal->SetUnitID (((ACOutputTerminalDescriptorPtr)theInterfacePtr)->bTerminalID);
@@ -1660,7 +1660,7 @@ USBInterfaceDescriptorPtr USBAudioControlObject::ParseACInterfaceDescriptor (USB
 				{
 				UInt8						numControls;
 
-                debugIOLog ("in FEATURE_UNIT in ParseACInterfaceDescriptor\n");
+                debugIOLog ("in FEATURE_UNIT in ParseACInterfaceDescriptor");
 				featureUnit = new USBFeatureUnitObject;
 				FailIf (NULL == featureUnit, Exit);
                 featureUnit->SetUnitID (((ACFeatureUnitDescriptorPtr)theInterfacePtr)->bUnitID);
@@ -1668,7 +1668,7 @@ USBInterfaceDescriptorPtr USBAudioControlObject::ParseACInterfaceDescriptor (USB
                 featureUnit->SetControlSize (((ACFeatureUnitDescriptorPtr)theInterfacePtr)->bControlSize);
                 // subtract 7 because that's how many fields are guaranteed to be in the struct
 				numControls = (((ACFeatureUnitDescriptorPtr)theInterfacePtr)->bLength - 7) / ((ACFeatureUnitDescriptorPtr)theInterfacePtr)->bControlSize;
-				debug2IOLog ("There are %d controls on this feature unit\n", numControls);
+				debugIOLog ("There are %d controls on this feature unit", numControls);
 				featureUnit->InitControlsArray (&((ACFeatureUnitDescriptorPtr)theInterfacePtr)->bmaControls[0], numControls);
 
 				if (NULL == theFeatureUnits) {
@@ -1687,23 +1687,23 @@ USBInterfaceDescriptorPtr USBAudioControlObject::ParseACInterfaceDescriptor (USB
 				UInt16 *					channelConfig;
 				UInt8						nrChannels;
 
-                debugIOLog ("in MIXER_UNIT in ParseACInterfaceDescriptor\n");
+                debugIOLog ("in MIXER_UNIT in ParseACInterfaceDescriptor");
 				mixerUnit = new USBMixerUnitObject;
 				FailIf (NULL == mixerUnit, Exit);
-				debug2IOLog ("descriptor length = %d\n", theInterfacePtr->bLength);
+				debugIOLog ("descriptor length = %d", theInterfacePtr->bLength);
 				mixerUnit->SetUnitID (((ACMixerUnitDescriptorPtr)theInterfacePtr)->bUnitID);
-				debug2IOLog ("unit ID = %d\n", ((ACMixerUnitDescriptorPtr)theInterfacePtr)->bUnitID);
-				debug2IOLog ("numInPins = %d\n", ((ACMixerUnitDescriptorPtr)theInterfacePtr)->bNrInPins);
+				debugIOLog ("unit ID = %d", ((ACMixerUnitDescriptorPtr)theInterfacePtr)->bUnitID);
+				debugIOLog ("numInPins = %d", ((ACMixerUnitDescriptorPtr)theInterfacePtr)->bNrInPins);
 				mixerUnit->InitSourceIDs (&((ACMixerUnitDescriptorPtr)theInterfacePtr)->baSourceID[0], ((ACMixerUnitDescriptorPtr)theInterfacePtr)->bNrInPins);
 				nrChannels = ((ACMixerUnitDescriptorPtr)theInterfacePtr)->baSourceID[((ACMixerUnitDescriptorPtr)theInterfacePtr)->bNrInPins];
-				debug2IOLog ("nrChannels = %d\n", nrChannels);
+				debugIOLog ("nrChannels = %d", nrChannels);
 				mixerUnit->SetNumChannels (nrChannels);
 				channelConfig = (UInt16 *)&((ACMixerUnitDescriptorPtr)theInterfacePtr)->baSourceID[((ACMixerUnitDescriptorPtr)theInterfacePtr)->bNrInPins + 1];
 				*channelConfig = USBToHostWord (*channelConfig);
-				debug2IOLog ("channelConfig = %d\n", *channelConfig);
+				debugIOLog ("channelConfig = %d", *channelConfig);
 				mixerUnit->SetChannelConfig (*channelConfig);
 				controlSize = ((ACMixerUnitDescriptorPtr)theInterfacePtr)->bLength - 10 - ((ACMixerUnitDescriptorPtr)theInterfacePtr)->bNrInPins;
-				debug2IOLog ("controlSize = %d\n", controlSize);
+				debugIOLog ("controlSize = %d", controlSize);
 				mixerUnit->InitControlsArray (&((ACMixerUnitDescriptorPtr)theInterfacePtr)->baSourceID[((ACMixerUnitDescriptorPtr)theInterfacePtr)->bNrInPins + 3], controlSize);
 
 				if (NULL == theMixerUnits) {
@@ -1717,12 +1717,12 @@ USBInterfaceDescriptorPtr USBAudioControlObject::ParseACInterfaceDescriptor (USB
 				break;
 				}
             case SELECTOR_UNIT:
-                debugIOLog ("in SELECTOR_UNIT in ParseACInterfaceDescriptor\n");
+                debugIOLog ("in SELECTOR_UNIT in ParseACInterfaceDescriptor");
 				selectorUnit = new USBSelectorUnitObject;
 				FailIf (NULL == selectorUnit, Exit);
 				selectorUnit->SetUnitID (((ACSelectorUnitDescriptorPtr)theInterfacePtr)->bUnitID);
 				selectorUnit->InitSourceIDs (&((ACSelectorUnitDescriptorPtr)theInterfacePtr)->baSourceID[0], ((ACSelectorUnitDescriptorPtr)theInterfacePtr)->bNrInPins);
-				debug2IOLog ("numInPins on selector = %d\n", ((ACSelectorUnitDescriptorPtr)theInterfacePtr)->bNrInPins);
+				debugIOLog ("numInPins on selector = %d", ((ACSelectorUnitDescriptorPtr)theInterfacePtr)->bNrInPins);
 
 				if (NULL == theSelectorUnits) {
 					theSelectorUnits = OSArray::withObjects ((const OSObject **)&selectorUnit, 1);
@@ -1734,19 +1734,19 @@ USBInterfaceDescriptorPtr USBAudioControlObject::ParseACInterfaceDescriptor (USB
 				selectorUnit->release ();
 				break;
             case PROCESSING_UNIT:
-                debugIOLog ("in PROCESSING_UNIT in ParseACInterfaceDescriptor\n");
+                debugIOLog ("in PROCESSING_UNIT in ParseACInterfaceDescriptor");
 				break;
             case EXTENSION_UNIT:
-                debugIOLog ("in EXTENSION_UNIT in ParseACInterfaceDescriptor\n");
+                debugIOLog ("in EXTENSION_UNIT in ParseACInterfaceDescriptor");
 				break;
             default:
-                debugIOLog ("in default in ParseACInterfaceDescriptor\n");
+                debugIOLog ("in default in ParseACInterfaceDescriptor");
         }
 		theInterfacePtr = (USBInterfaceDescriptorPtr)((UInt8 *)theInterfacePtr + theInterfacePtr->bLength);
     }
 
 Exit:
-	debug3IOLog ("-USBAudioControlObject::ParseACInterfaceDescriptor (%p, %d)\n", theInterfacePtr, currentInterface);
+	debugIOLog ("-USBAudioControlObject::ParseACInterfaceDescriptor (%p, %d)", theInterfacePtr, currentInterface);
     return theInterfacePtr;
 }
 
@@ -1829,14 +1829,14 @@ UInt8 USBAudioStreamObject::GetIsocEndpointAddress (UInt8 direction) {
 
     indx = 0;
 	address = 0;
-	debug2IOLog ("GetIsocEndpointAddress, looking for direction %d\n", direction);
+	debugIOLog ("GetIsocEndpointAddress, looking for direction %d", direction);
 	if (theEndpointObjects) {
 		while (!address && indx < theEndpointObjects->getCount ()) {
 			thisEndpointObject = GetIndexedEndpointObject (indx);
-			debug2IOLog ("GetIsocEndpointAddress, this endpoint's direction %d\n", thisEndpointObject->GetDirection ());
+			debugIOLog ("GetIsocEndpointAddress, this endpoint's direction %d", thisEndpointObject->GetDirection ());
 			if (thisEndpointObject && direction == thisEndpointObject->GetDirection ()) {
 				address = thisEndpointObject->GetAddress ();
-				debug2IOLog ("GetIsocEndpointAddress, found endpoint address %d\n", address);
+				debugIOLog ("GetIsocEndpointAddress, found endpoint address %d", address);
 			}
 		indx++;
 		}
@@ -1886,7 +1886,7 @@ USBInterfaceDescriptorPtr USBAudioStreamObject::ParseASInterfaceDescriptor (USBI
     Boolean								done;
     USBEndpointObject *					theEndpoint;
 
-	debug3IOLog ("+USBAudioStreamObject::ParseASInterfaceDescriptor (%x, %d)\n", theInterfacePtr, currentInterface);
+	debugIOLog ("+USBAudioStreamObject::ParseASInterfaceDescriptor (%x, %d)", theInterfacePtr, currentInterface);
 
     FailIf (NULL == theInterfacePtr, Exit);
     FailIf (0 == theInterfacePtr->bLength, Exit);
@@ -1897,24 +1897,24 @@ USBInterfaceDescriptorPtr USBAudioStreamObject::ParseASInterfaceDescriptor (USBI
         if (CS_INTERFACE == theInterfacePtr->bDescriptorType) {
             switch (theInterfacePtr->bDescriptorSubtype) {
                 case AS_GENERAL:
-                    debugIOLog ("in AS_GENERAL in ParseASInterfaceDescriptor\n");
+                    debugIOLog ("in AS_GENERAL in ParseASInterfaceDescriptor");
                     terminalLink = ((ASInterfaceDescriptorPtr)theInterfacePtr)->bTerminalLink;
                     delay = ((ASInterfaceDescriptorPtr)theInterfacePtr)->bDelay;
                     formatTag = USBToHostWord ((((ASInterfaceDescriptorPtr)theInterfacePtr)->wFormatTag[1] << 8) | ((ASInterfaceDescriptorPtr)theInterfacePtr)->wFormatTag[0]);
                     theInterfacePtr = (USBInterfaceDescriptorPtr)((UInt8 *)theInterfacePtr + theInterfacePtr->bLength);
                     break;
                 case FORMAT_TYPE:
-                    debugIOLog ("in FORMAT_TYPE in ParseASInterfaceDescriptor\n");
+                    debugIOLog ("in FORMAT_TYPE in ParseASInterfaceDescriptor");
 					switch (((ASFormatTypeIDescriptorPtr)theInterfacePtr)->bFormatType) {
 						case FORMAT_TYPE_I:
 						case FORMAT_TYPE_III:
-							debugIOLog ("in FORMAT_TYPE_I/FORMAT_TYPE_III in FORMAT_TYPE\n");
+							debugIOLog ("in FORMAT_TYPE_I/FORMAT_TYPE_III in FORMAT_TYPE");
 							numChannels = ((ASFormatTypeIDescriptorPtr)theInterfacePtr)->bNrChannels;
 							subframeSize = ((ASFormatTypeIDescriptorPtr)theInterfacePtr)->bSubframeSize;
 							bitResolution = ((ASFormatTypeIDescriptorPtr)theInterfacePtr)->bBitResolution;
 							numSampleFreqs = ((ASFormatTypeIDescriptorPtr)theInterfacePtr)->bSamFreqType;
 							if (0 != numSampleFreqs) {
-								debugIOLog ("device has a discrete number of sample rates\n");
+								debugIOLog ("device has a discrete number of sample rates");
 								sampleFreqs = (UInt32 *)IOMalloc (numSampleFreqs * sizeof (UInt32));
 								for (indx = 0; indx < numSampleFreqs; indx++) {
 									sampleFreqs[indx] = ConvertSampleFreq( &((ASFormatTypeIDescriptorPtr)theInterfacePtr)->sampleFreq[indx * 3] );
@@ -1924,7 +1924,7 @@ USBInterfaceDescriptorPtr USBAudioStreamObject::ParseASInterfaceDescriptor (USBI
 									((UInt8 *)sampleFreqs)[indx * 4 + 3] = ((ASFormatTypeIDescriptorPtr)theInterfacePtr)->sampleFreq[indx * 3]; */
 								}
 							} else {
-								debugIOLog ("device has a variable number of sample rates\n");
+								debugIOLog ("device has a variable number of sample rates");
 								sampleFreqs = (UInt32 *)IOMalloc (2 * sizeof (UInt32));
 								for (indx = 0; indx < 2; indx++) {
 									sampleFreqs[indx] = ConvertSampleFreq( &((ASFormatTypeIDescriptorPtr)theInterfacePtr)->sampleFreq[indx * 3] );
@@ -1936,12 +1936,12 @@ USBInterfaceDescriptorPtr USBAudioStreamObject::ParseASInterfaceDescriptor (USBI
 							}
 							break;
 						case FORMAT_TYPE_II:
-							debugIOLog ("in FORMAT_TYPE_II in FORMAT_TYPE\n");
+							debugIOLog ("in FORMAT_TYPE_II in FORMAT_TYPE");
 							maxBitRate = USBToHostWord (((ASFormatTypeIIDescriptorPtr)theInterfacePtr)->wMaxBitRate);
 							samplesPerFrame = USBToHostWord (((ASFormatTypeIIDescriptorPtr)theInterfacePtr)->wSamplesPerFrame);
 							numSampleFreqs = ((ASFormatTypeIIDescriptorPtr)theInterfacePtr)->bSamFreqType;
 							if (0 != numSampleFreqs) {
-								debugIOLog ("device has a discrete number of sample rates\n");
+								debugIOLog ("device has a discrete number of sample rates");
 								sampleFreqs = (UInt32 *)IOMalloc (numSampleFreqs * sizeof (UInt32));
 								for (indx = 0; indx < numSampleFreqs; indx++) {
 									sampleFreqs[indx] = ConvertSampleFreq( &((ASFormatTypeIIDescriptorPtr)theInterfacePtr)->sampleFreq[indx * 3] );
@@ -1951,7 +1951,7 @@ USBInterfaceDescriptorPtr USBAudioStreamObject::ParseASInterfaceDescriptor (USBI
 									((UInt8 *)sampleFreqs)[indx * 4 + 3] = ((ASFormatTypeIIDescriptorPtr)theInterfacePtr)->sampleFreq[indx * 3]; */
 								}
 							} else {
-								debugIOLog ("device has a variable number of sample rates\n");
+								debugIOLog ("device has a variable number of sample rates");
 								sampleFreqs = (UInt32 *)IOMalloc (2 * sizeof (UInt32));
 								for (indx = 0; indx < 2; indx++) {
 									sampleFreqs[indx] = ConvertSampleFreq( &((ASFormatTypeIIDescriptorPtr)theInterfacePtr)->sampleFreq[indx * 3] );
@@ -1963,23 +1963,23 @@ USBInterfaceDescriptorPtr USBAudioStreamObject::ParseASInterfaceDescriptor (USBI
 							}
 							break;
 						default:
-							debugIOLog ("!!!!unknown format type in FORMAT_TYPE!!!!\n");
+							debugIOLog ("!!!!unknown format type in FORMAT_TYPE!!!!");
 					}
                     theInterfacePtr = (USBInterfaceDescriptorPtr)((UInt8 *)theInterfacePtr + theInterfacePtr->bLength);
                     break;
 				case FORMAT_SPECIFIC:
-                    debugIOLog ("in FORMAT_SPECIFIC in ParseASInterfaceDescriptor\n");
+                    debugIOLog ("in FORMAT_SPECIFIC in ParseASInterfaceDescriptor");
 					wFormatTag = USBToHostWord (((ASFormatSpecificDescriptorHeaderPtr)theInterfacePtr)->wFormatTag[1] << 8 | ((ASFormatSpecificDescriptorHeaderPtr)theInterfacePtr)->wFormatTag[0]);
 					switch (wFormatTag) {
 						case MPEG:
-							debugIOLog ("in FORMAT_SPECIFIC in MPEG\n");
+							debugIOLog ("in FORMAT_SPECIFIC in MPEG");
 							bmMPEGCapabilities = USBToHostWord(
 												((ASMPEGFormatSpecificDescriptorPtr)theInterfacePtr)->bmMPEGCapabilities[1] << 8 |
 												((ASMPEGFormatSpecificDescriptorPtr)theInterfacePtr)->bmMPEGCapabilities[0]);
 							bmMPEGFeatures = ((ASMPEGFormatSpecificDescriptorPtr)theInterfacePtr)->bmMPEGFeatures;
 							break;
 						case AC3:
-							debugIOLog ("in FORMAT_SPECIFIC in AC3\n");
+							debugIOLog ("in FORMAT_SPECIFIC in AC3");
 							bmAC3BSID = USBToHostLong(
 										((ASAC3FormatSpecificDescriptorPtr)theInterfacePtr)->bmBSID[3] << 24 |
 										((ASAC3FormatSpecificDescriptorPtr)theInterfacePtr)->bmBSID[2] << 16 |
@@ -1988,24 +1988,24 @@ USBInterfaceDescriptorPtr USBAudioStreamObject::ParseASInterfaceDescriptor (USBI
 							bmAC3Features = ((ASAC3FormatSpecificDescriptorPtr)theInterfacePtr)->bmAC3Features;
 							break;
 						default:
-							debug2IOLog ("!!!!unknown format type 0x%x in FORMAT_SPECIFIC!!!!\n", wFormatTag);
+							debugIOLog ("!!!!unknown format type 0x%x in FORMAT_SPECIFIC!!!!", wFormatTag);
 							break;
 					}
                     theInterfacePtr = (USBInterfaceDescriptorPtr)((UInt8 *)theInterfacePtr + theInterfacePtr->bLength);
                     break;
                 default:
-                    debugIOLog ("in default in ParseASInterfaceDescriptor\n");
+                    debugIOLog ("in default in ParseASInterfaceDescriptor");
                     theInterfacePtr = (USBInterfaceDescriptorPtr)((UInt8 *)theInterfacePtr + theInterfacePtr->bLength);
             }
         } else {
             switch (theInterfacePtr->bDescriptorType) {
                 case INTERFACE:
                     // need to make a new interface object for this new interface or new alternate interface
-                    debugIOLog ("in INTERFACE in ParseASInterfaceDescriptor\n");
+                    debugIOLog ("in INTERFACE in ParseASInterfaceDescriptor");
                     done = TRUE;
                     break;
                 case ENDPOINT:
-                    debugIOLog ("in ENDPOINT in ParseASInterfaceDescriptor\n");
+                    debugIOLog ("in ENDPOINT in ParseASInterfaceDescriptor");
                     theEndpoint = USBEndpointObject::create ();
 					theEndpoint->SetAddress (((USBEndpointDescriptorPtr)theInterfacePtr)->bEndpointAddress);
                     theEndpoint->SetAttributes (((USBEndpointDescriptorPtr)theInterfacePtr)->bmAttributes);
@@ -2024,9 +2024,9 @@ USBInterfaceDescriptorPtr USBAudioStreamObject::ParseASInterfaceDescriptor (USBI
                     theInterfacePtr = (USBInterfaceDescriptorPtr)((UInt8 *)theInterfacePtr + theInterfacePtr->bLength);
                     break;
                 case CS_ENDPOINT:
-                    debugIOLog ("in CS_ENDPOINT in ParseASInterfaceDescriptor\n");
+                    debugIOLog ("in CS_ENDPOINT in ParseASInterfaceDescriptor");
                     if (EP_GENERAL == ((ASEndpointDescriptorPtr)theInterfacePtr)->bDescriptorSubtype) {
-                        debugIOLog ("in EP_GENERAL in CS_ENDPOINT\n");
+                        debugIOLog ("in EP_GENERAL in CS_ENDPOINT");
                         theIsocEndpointObject = new USBCSASIsocADEndpointObject (((ASEndpointDescriptorPtr)theInterfacePtr)->bmAttributes & (1 << sampleFreqControlBit),
                                                                             ((ASEndpointDescriptorPtr)theInterfacePtr)->bmAttributes & (1 << pitchControlBit),
                                                                             ((ASEndpointDescriptorPtr)theInterfacePtr)->bmAttributes & (1 << maxPacketsOnlyBit),
@@ -2036,14 +2036,14 @@ USBInterfaceDescriptorPtr USBAudioStreamObject::ParseASInterfaceDescriptor (USBI
                     theInterfacePtr = (USBInterfaceDescriptorPtr)((UInt8 *)theInterfacePtr + theInterfacePtr->bLength);
                     break;
                 default:
-                    debugIOLog ("in default in else in ParseASInterfaceDescriptor\n");
+                    debugIOLog ("in default in else in ParseASInterfaceDescriptor");
                     theInterfacePtr = (USBInterfaceDescriptorPtr)((UInt8 *)theInterfacePtr + theInterfacePtr->bLength);
             }
         }
     }
 
 Exit:
-	debug3IOLog ("-USBAudioStreamObject::ParseASInterfaceDescriptor (%x, %d)\n", theInterfacePtr, currentInterface);
+	debugIOLog ("-USBAudioStreamObject::ParseASInterfaceDescriptor (%x, %d)", theInterfacePtr, currentInterface);
     return theInterfacePtr;
 }
 
@@ -2171,8 +2171,8 @@ void USBMixerUnitObject::InitControlsArray (UInt8 * bmCntrls, UInt8 bmControlSiz
 	FailIf (NULL == bmControls, Exit);
 	memcpy (bmControls, bmCntrls, bmControlSize);
 	for (i = 0; i < bmControlSize; i++) {
-		debug3IOLog ("bmCntrls[%d] = 0x%X\n", i, bmCntrls[i]);
-		debug3IOLog ("bmControls[%d] = 0x%X\n", i, bmControls[i]);
+		debugIOLog ("bmCntrls[%d] = 0x%X", i, bmCntrls[i]);
+		debugIOLog ("bmControls[%d] = 0x%X", i, bmControls[i]);
 	}
 Exit:
 	return;
@@ -2188,7 +2188,7 @@ void USBMixerUnitObject::InitSourceIDs (UInt8 * baSrcIDs, UInt8 nrInPins) {
 	{
 		UInt8			i;
 		for (i = 0; i < nrInPins; i++) {
-			debug3IOLog ("baSourceIDs[%d] = %d\n", i, baSourceIDs[i]);
+			debugIOLog ("baSourceIDs[%d] = %d", i, baSourceIDs[i]);
 		}
 	}
 #endif
